;*******************************************************************************************
;   Beschreibung:	Aktivboxsteuerung mit 4 Mhz Quarz								 * 
;																														 *							 *
;*******************************************************************************************
;                                                                                          *
;    Dateiname:	 	AB_Steuerung.asm						                               		 *
;    Datum:        	08.12.2014                                                            *
;    Version: 			V0.0                                                                  *
;                                                                                          *
;    Autor:       	Werner Hirsch                                                       *
;    Internet:      www.wernerhirsch.de                                                           *
;    e-mail:		wernerhirschhh@aol.com                                                          *
;                                                                                          *
;*******************************************************************************************
;    Bemerkungen:                                                                          *
;																														 *
;	Bankumschaltungen:
;	BANK_0:	BCF STATUS,RP0
;			BCF STATUS,RP1
;	BANK_1:	BSF STATUS,RP0
;			BCF STATUS,RP1
;	BANK_2:	BCF STATUS,RP0
;			BSF STATUS,RP1
;	BANK_3:	BSF STATUS,RP0
;			BSF STATUS,RP1														 *
;                                                                                          *
;*******************************************************************************************


	list      p=16f877a			;definiert den verwendeten Prozessor
	#include <p16f877a.inc>		;in diesem File stehen die Adressen und Bitnamen

	ERRORLEVEL      -302		;SUPPRESS BANK SELECTION MESSAGES
	ERRORLEVEL      -305		;SUPPRESS BANK SELECTION MESSAGES
	ERRORLEVEL      -306		;SUPPRESS BANK SELECTION MESSAGES
	
	__CONFIG _CP_OFF & _WDT_OFF & _BODEN_OFF & _PWRTE_OFF & _XT_OSC & _WRT_OFF & _LVP_OFF & _DEBUG_OFF & _CPD_OFF 
	; Mit '__CONFIG' werden die Configurationsbits gesetzt, z.B. Watchdog an/aus, Debugmodus


;===========================
;  DEFINITIONEN
;===========================
#define OUT_CS_VOL		PORTA, 0		;PIN RA0 (pin 2) Ausgang Chip Select (AD5262) 
#define OUT_SDI_VOL		PORTA, 1		;PIN RA1 (pin 3) Ausgang Daten (AD5262) 
#define OUT_CLK_VOL		PORTA, 2		;PIN RA2 (pin 4) Ausgang Clock (AD5262) 
#define OUT_SHD_VOL		PORTA, 3		;PIN RA3 (pin 5) Ausgang Shut Down (AD5262) 
#define OUT_BASS		PORTA, 4		;PIN RA4 (pin 6) Ausgang Bass
#define OUT_POWER		PORTA, 5		;PIN RA5 (pin 7) Ausgang Power (schaltet V+/- Audio und Netz Boxen ein/aus)
#define IN_IR			PORTB, 0		;Pin RB0 (pin 33) Eingang Infrarotempfnger 
#define IN_MENU			PORTB, 1		;Pin RB1 (pin 34) Eingang Taster Men
#define IN_OK			PORTB, 2		;Pin RB2 (pin 35) Eingang Taster OK
#define IN_VOL_P		PORTB, 3		;Pin RB3 (pin 36) Eingang Taster Lautstrke +
#define IN_VOL_M		PORTB, 4		;Pin RB4 (pin 37) Eingang Taster Lautstrke -
#define IN_CHA_P		PORTB, 5		;Pin RB5 (pin 38) Eingang Taster Kanal +
#define IN_CHA_M		PORTB, 6		;Pin RB6 (pin 39) Eingang Taster Kanal -
#define IN_ONOFF		PORTB, 7		;Pin RB7 (pin 40) Eingang Taster 1/0
#define OUT_KH			PORTC, 0		;PIN RC0 (pin 15) Ausgang Abschaltung Boxen (bei Kopfhrerbetrieb)
#define IN_CH1			PORTC, 1		;PIN RC1 (pin 16) Schaltkontakt Eingang 1 (Master fr Auto On/Off)
#define IN_CH2			PORTC, 2		;PIN RC2 (pin 17) Schaltkontakt Eingang 2
#define IN_CH3			PORTC, 3		;PIN RC3 (pin 18) Schaltkontakt Eingang 3
#define OUT_RS			PORTC, 4		;PIN RC4 (pin 23) Unterscheidung zwischen Befehl und Daten
#define OUT_ENABLE		PORTC, 5		;PIN RC5 (pin 24) Mit Enable werden die parallelen Daten ins Display bernommen 
#define OUT_SDA			PORTC, 6		;PIN RC6 (pin 25) Serielle Daten zum Schieberegister
#define OUT_CLK			PORTC, 7		;PIN RC7 (pin 26) Takt fr die Displaydaten
#define IN_CH4			PORTD, 0		;PIN RD0 (pin 19) Schaltkontakt Eingang 4
#define IN_CH5			PORTD, 1		;PIN RD1 (pin 20) Schaltkontakt Eingang 5
#define IN_KH			PORTD, 2		;PIN RD2 (pin 21) Schaltkontakt Kopfhrer
#define IN_CH6			PORTD, 3		;PIN RD3 (pin 22) Schaltkontakt Eingang 6 (Front)
#define IN_CH8			PORTD, 4		;PIN RD4 (pin 27) Schaltkontakt Eingang 8
#define IN_CH7			PORTD, 5		;PIN RD5 (pin 28) Schaltkontakt Eingang 7
#define IN_CLIP			PORTD, 6		;PIN RD6 (pin 29) Eingang Clip Detection von Boxen
#define OUT_BOX			PORTD, 7		;PIN RD7 (pin 30) Ausgang Mute an Boxen
#define OUT_CHDB2		PORTE, 0		;PIN RE0 (pin  8) Ausgang Kanalwahl DB2
#define OUT_CHDB1		PORTE, 1		;PIN RE1 (pin  9) Ausgang Kanalwahl DB1
#define OUT_CHDB0		PORTE, 2		;PIN RE2 (pin 10) Ausgang Kanalwahl DB0

;===========================
;  KONSTANTEN
;===========================


;===========================
;  VARIABLEN
;===========================
w_temp        	EQU	0x7D        ; werden fr Interrupts verwendet, um den Status vor 
status_temp   	EQU	0x7E        ; der Interruptroutine zu sichern
pclath_temp		EQU	0x7F

BEFEHL			EQU	0x20		;Register fr Tasten und IR-Befehl
VOLUME			EQU	0x21		;
VOL_BIN			EQU	0x22		;
LOOP_1			EQU 0x23		;Zhler1 fr Wartezeit
LOOP_2			EQU 0x24		;Zhler2 fr Wartezeit
TEMP_10			EQU	0x25		;Allgemeines temporres Register
TEMP_11			EQU	0x26		;Allgemeines temporres Register
TEMP_12			EQU	0x27		;Allgemeines temporres Register
TEMP_13			EQU	0x28		;Allgemeines temporres Register
TEMP_14			EQU	0x29		;Allgemeines temporres Register
TEMP_15			EQU	0x2A		;Allgemeines temporres Register
TEMP_16			EQU	0x2B		;Allgemeines temporres Register
TEMP_17			EQU	0x2C		;Allgemeines temporres Register
TEMP_18			EQU	0x2D		;Allgemeines temporres Register
SHIFT_REG		EQU	0x2E		;Datum, welches seriell gesendet werden soll
SHIFT_COUNT		EQU	0x2F		;Zhler fr die serielle Datenausgabe

COUNTER			EQU	0x30		;Allgemeines Zhlregister
IR_START2		EQU 0x31		;Register fr 2.Startbit
IR_STRG			EQU	0x32		;Register fr Steuerbit
IR_ADR			EQU	0x33		;Register fr die RC5 Adresse
IR_BEF			EQU	0x34		;Register fr den RC5 Befehl
IR_BIT			EQU 0x35		;Status IR Bit: Bit0 = 1.Hlfte,  100 = Fehler, 001 = 0, 010 = 1, 111 = Fehler
								;				Bit1 = 2.Hlfte
								;				Bit2 = Fehlerbit
IR_TEMP			EQU	0x36		;Temp Register fr Zwischspeicherung des gesendeten bytes
IR_ADR_1		EQU	0x37		;Register fr die RC5 Adresse 1
IR_ADR_2		EQU	0x38		;Register fr die RC5 Adresse 2
IR_ADR_3		EQU	0x39		;Register fr die RC5 Adresse 3
IR_BEF_BAS		EQU	0x3A		;Register fr IR-Befehl Bassanhebung
IR_BEF_MEN		EQU 0x3B		;Register fr IR-Befehl Men
IR_BEF_OK		EQU 0x3C		;Register fr IR-Befehl OK
IR_NEU			EQU 0x3D		;Statusregister:	Bit0 = neuer IR-Befehl	
CHANNEL			EQU	0x3E		;Register fr Eingangskanal
CHA_MAX			EQU	0x3F		;Register fr Anzahl Eingnge
TEXT_DIG1		EQU	0x40		;Register fr Text Kanal 1-8, Digit 1
TEXT_DIG2		EQU	0x41		;Register fr Text Kanal 1-8, Digit 2
TEXT_DIG3		EQU	0x42		;Register fr Text Kanal 1-8, Digit 3
TEXT_DIG4		EQU	0x43		;Register fr Text Kanal 1-8, Digit 4
TEXT_DIG5		EQU	0x44		;Register fr Text Kanal 1-8, Digit 5
TEXT_DIG6		EQU	0x45		;Register fr Text Kanal 1-8, Digit 6
TEXT_DIG7		EQU	0x46		;Register fr Text Kanal 1-8, Digit 7
TEXT_DIG8		EQU	0x47		;Register fr Text Kanal 1-8, Digit 8
CHA_AUTO		EQU	0x48		;Register fr automatische Eingangswahl, 0=auto, 1=manuell
CHANNEL_ALT		EQU	0x49		;Register fr Eingangskanal Alt
CH1_ALT			EQU	0x4A		;Register fr alten Status Eingang 1: 1=eingeschaltet, 0=ausgeschaltet (Master)
DISP_NEU		EQU	0x4B		;Statusregister Display:
								;Bit0: Normalanzeige, Bit1: -, Bit2: -, Bit3: -
								;Bit4: Menue 1.Stufe, Bit5: -, Bit6: -, Bit7: -
MENUE_FF		EQU 0x50		;Statusregister: bit 0 = Menuemodus, 
MENUE_COUNT		EQU 0x51		;Zhler fr Menposition vertikal
MENUE_1_CNT		EQU 0x52		;Zhler
TEMP_DIG_CNT	EQU 0x53		;Zhler fr Menposition horizontal
TEMP_CNT_MAX	EQU 0x54		;Max Zhlerwert fr Menposition horizontal
TEMP_DIG_ADR	EQU 0x55		;Display Adressregister fr das zu ndernde Digit
TEMP_DIG_VAL	EQU 0x56		;Display Wert fr das zu ndernde Digit
TEMP_VAL_PREV	EQU 0x57		;Display Wert fr das vorhergehende zu ndernde Digit
TEMP_DIG_STAT	EQU 0x58		;Status Register	bit 0: wenn 1: Update der Anzeige des zu ndernden Wertes
								;					bit 1: wenn 1: Erhhung des zu ndernden Wertes
								;					bit 2: wenn 1: Reduzierung des zu ndernden Wertes
KH_ALT			EQU 0x59		;Status des Kopfhrereingangs alt 
POTI_TYP		EQU 0x5A		;Register fr Potentiometer Typ:  0 = AD5262, 1 = Eigenbau
CHA_AUTOMAN		EQU 0x5B		;Register fr Betriebsart Kanalwahl:  0 = Auto (Priorittssteuerung), 1 = Manuell
;__________________________________________________________________________________________
;
		ORG 	H'2100'			;Adresse des EEPROM fr den Brenner (2100 = erster Speicherplatz)
;Konstanten Startlautstrke
		de		0x0F			;Adresse 00,	Kanal 1
		de		0x0F			;Adresse 01,	Kanal 2
		de		0x01			;Adresse 02,	Kanal 3 
		de		0x05			;Adresse 03,	Kanal 4
		de		0x05			;Adresse 04,	Kanal 5
		de		0x0F			;Adresse 05,	Kanal 6
		de		0x01			;Adresse 06,	Kanal 7
		de		0x01			;Adresse 07,	Kanal 8
;Konstanten Text der Kanle
		de		0x52			;Adresse 08,	Kanal 1, Digit 1	
		de		0x41			;Adresse 09,	Kanal 1, Digit 2	
		de		0x44			;Adresse 10,	Kanal 1, Digit 3	
		de		0x49			;Adresse 11,	Kanal 1, Digit 4	
		de		0x4F			;Adresse 12,	Kanal 1, Digit 5	
		de		0x20			;Adresse 13,	Kanal 1, Digit 6	
		de		0x20			;Adresse 14,	Kanal 1, Digit 7	
		de		0x20			;Adresse 15,	Kanal 1, Digit 8	
		de		0x53			;Adresse 16,	Kanal 2, Digit 1	
		de		0x41			;Adresse 17,	Kanal 2, Digit 2	
		de		0x54			;Adresse 18,	Kanal 2, Digit 3	
		de		0x20			;Adresse 19,	Kanal 2, Digit 4	
		de		0x20			;Adresse 20,	Kanal 2, Digit 5	
		de		0x20			;Adresse 21,	Kanal 2, Digit 6	
		de		0x20			;Adresse 22,	Kanal 2, Digit 7	
		de		0x20			;Adresse 23,	Kanal 2, Digit 8	
		de		0x44			;Adresse 24,	Kanal 3, Digit 1	
		de		0x56			;Adresse 25,	Kanal 3, Digit 2	
		de		0x44			;Adresse 26,	Kanal 3, Digit 3	
		de		0x20			;Adresse 27,	Kanal 3, Digit 4	
		de		0x20			;Adresse 28,	Kanal 3, Digit 5	
		de		0x20			;Adresse 29,	Kanal 3, Digit 6	
		de		0x20			;Adresse 30,	Kanal 3, Digit 7	
		de		0x20			;Adresse 31,	Kanal 3, Digit 8	
		de		0x50			;Adresse 32,	Kanal 4, Digit 1	
		de		0x48			;Adresse 33,	Kanal 4, Digit 2	
		de		0x4F			;Adresse 34,	Kanal 4, Digit 3	
		de		0x4E			;Adresse 35,	Kanal 4, Digit 4	
		de		0x4F			;Adresse 36,	Kanal 4, Digit 5	
		de		0x20			;Adresse 37,	Kanal 4, Digit 6	
		de		0x20			;Adresse 38,	Kanal 4, Digit 7	
		de		0x20			;Adresse 39,	Kanal 4, Digit 8	
		de		0x4C			;Adresse 40,	Kanal 5, Digit 1	
		de		0x45			;Adresse 41,	Kanal 5, Digit 2	
		de		0x45			;Adresse 42,	Kanal 5, Digit 3	
		de		0x52			;Adresse 43,	Kanal 5, Digit 4	
		de		0x31			;Adresse 44,	Kanal 5, Digit 5	
		de		0x20			;Adresse 45,	Kanal 5, Digit 6	
		de		0x20			;Adresse 46,	Kanal 5, Digit 7	
		de		0x20			;Adresse 47,	Kanal 5, Digit 8	
		de		0x46			;Adresse 48,	Kanal 6, Digit 1	
		de		0x52			;Adresse 49,	Kanal 6, Digit 2	
		de		0x4F			;Adresse 50,	Kanal 6, Digit 3	
		de		0x4E			;Adresse 51,	Kanal 6, Digit 4	
		de		0x54			;Adresse 52,	Kanal 6, Digit 5	
		de		0x20			;Adresse 53,	Kanal 6, Digit 6	
		de		0x20			;Adresse 54,	Kanal 6, Digit 7	
		de		0x20			;Adresse 55,	Kanal 6, Digit 8	
		de		0x4C			;Adresse 56,	Kanal 7, Digit 1	
		de		0x45			;Adresse 57,	Kanal 7, Digit 2	
		de		0x45			;Adresse 58,	Kanal 7, Digit 3	
		de		0x52			;Adresse 59,	Kanal 7, Digit 4	
		de		0x32			;Adresse 60,	Kanal 7, Digit 5	
		de		0x20			;Adresse 61,	Kanal 7, Digit 6	
		de		0x20			;Adresse 62,	Kanal 7, Digit 7	
		de		0x20			;Adresse 63,	Kanal 7, Digit 8	
		de		0x4C			;Adresse 64,	Kanal 8, Digit 1	
		de		0x45			;Adresse 65,	Kanal 8, Digit 2	
		de		0x45			;Adresse 66,	Kanal 8, Digit 3	
		de		0x52			;Adresse 67,	Kanal 8, Digit 4	
		de		0x33			;Adresse 68,	Kanal 8, Digit 5	
		de		0x20			;Adresse 69,	Kanal 8, Digit 6	
		de		0x20			;Adresse 70,	Kanal 8, Digit 7	
		de		0x20			;Adresse 71,	Kanal 8, Digit 8	
;Konstanten Anzahl Kanle, IR-Adressen und IR-befehle
		de		0x06			;Adresse 72,	Anzahl Kanle	
		de		0x08			;Adresse 73,	IR-Adresse 1	
		de		0x11			;Adresse 74,	IR-Adresse 2	
		de		0x12			;Adresse 75,	IR-Adresse 3
		de		0x0F			;Adresse 76,	IR-Befehl Bassanhebung
		de		0x12			;Adresse 77,	IR-Befehl Men
		de		0x13			;Adresse 78,	IR-Befehl OK
;Konstante Auswahl Digitalpoti
		de		0x00			;Adresse 79,	0 = AD5262, 1 = Eigenbau
;Konstante Auswahl Betriebsart Kanalwahl
		de		0x00			;Adresse 80,	0 = Auto, 1 = Manuell
		de		0x02			;Adresse 81,	gespeicherte Kanalnummer		

;__________________________________________________________________________________________

		ORG     0x000			; Adresse, an die nach einem Reset gesprungen wird
		
  		goto    start           ; Springe zum Programmanfang

		ORG     0x004           ; Adresse, an die nach einem Interrupt gesprungen wird
		movwf	w_temp          ; Sichere den Inhalt des W-Registers
		movf    STATUS,w        ; Verschiebe STATUS-Register ins W-Register
		movwf	status_temp     ; Sichere den Inhalt des STATUS-Registers
		movf    PCLATH,w        ; Verschiebe PCLATH-Register ins W-Register
		movwf	pclath_temp     ; Sichere den Inhalt des PCLATH-Registers

	bcf PCLATH,3				;Select Page 0
	bcf PCLATH,4				;
	call ir_startbit			;Aufruf des Unterprogramms zur Auswertung des IR Signals
	bcf INTCON,INTF				;Lsche Interupt Bit

		movf    pclath_temp,w  	; hole die Kopie des PCLATH-Registers
		movwf	PCLATH         	; Sichere die Daten wieder zurck in das PCLATH-Register
		movf    status_temp,w  	; hole die Kopie des STATUS-Registers
		movwf	STATUS          ; Sichere die Daten wieder zurck in das STATUS-Register
		swapf   w_temp,f
		swapf   w_temp,w        ; Sichere die Daten wieder zurck in das W-Register
		retfie                  ; Rcksprung vom Interrupt
;__________________________________________________________________________________________

start							; Beginn des Programms
	; Initialisierungen
	bcf STATUS,RP0			;Select BANK_0
	bcf STATUS,RP1
	clrf PORTA				;Lsche alle Ausgangsports
	clrf PORTB
	clrf PORTC
	clrf PORTD
	clrf PORTE
	bsf STATUS,RP0			;Select BANK_1
	movlw b'00000110'		;alle Pins von Port A sind digitale Ein- oder Ausgnge
	movwf ADCON1
	movlw b'11000000'		;setze RA0 bis RA5 als Ausgang
	movwf TRISA
	movlw b'11111111'		;setze RB0-RB7 als Eingang
	movwf TRISB
	movlw b'00001110'		;setze RC1-RC3 als Eingang, den Rest als Ausgang
	movwf TRISC
	movlw b'01111111'		;setze RD0-RD6 als Eingang, den Rest als Ausgang
	movwf TRISD
	movlw b'00000000'		;setze RE0-RE2 als Ausgang
	movwf TRISE
	movlw b'00001000'		;pull-up, internen Takt zhlen, bit 3: TMR0 Vorteiler 1:1
	movwf OPTION_REG
	bcf STATUS,RP0			;Select BANK_0
	bcf OUT_SHD_VOL			;setze Ausgang Shut Down Volume auf low => Mute on
	bsf OUT_KH				;setze Kopfhrerer Ausgang auf high = Audioausgang Boxen ist abgeschaltet
	bcf OUT_BASS			;setze Bass Ausgang auf low = Bass off
	movlw b'00010000'		;bit0-2 interupt flags, bit3 RBIE disable, bit4 INTE enable, bit5 TMR0IE disable,
	movwf INTCON			;bit6 PEIE disable, bit7 GIE disable
	movlw b'00000100'		;TMR2 Prescaler 1:1
	movwf T2CON

	bsf OUT_POWER			;Einschalten der Versorgungsspannung fr Boxen und Audio

	clrf VOLUME
	movlw 0xFF
	movwf DISP_NEU
	movlw d'1'				;lade Register mit Wert 1
	movwf MENUE_FF			;
	call menue_stat			;Aufruf des Unterprogramms, Rcksetzen von MENUE_FF und laden der Startwerte
	bsf PCLATH,3			;Select Page 1
	call Init_display		;Initialisierung des Displays
	bcf PCLATH,3			;Select Page 0
							;Auslesen der Werte Aus dem EEPROM
	movlw d'72'				;Maximale Anzahl der Eingnge
	call readEE				;
	movwf CHA_MAX			;
	movlw d'73'				;Adresse 1 fr IR-Befehl, Befehl: 	Vol+ = 16, Vol- = 17, Mute = 13
	call readEE				;									Kanal+ = 32, Kanal- = 33
	movwf IR_ADR_1			;									Ziffern 0-9 = 0-9, Bassanhebung = 15
	movlw d'74'				;Adresse 2 fr IR-Befehl, 			Men = 41, On/Off = 12, OK = 38
	call readEE				;
	movwf IR_ADR_2			;									
	movlw d'75'				;Adresse 3 fr IR-Befehl,			
	call readEE				;
	movwf IR_ADR_3			;
	movlw d'76'				;IR-Befehl Bassanhebung = 15
	call readEE				;
	movwf IR_BEF_BAS		;
	movlw d'77'				;IR-Befehl Men = 41
	call readEE				;
	movwf IR_BEF_MEN		;
	movlw d'78'				;IR-Befehl OK = 38
	call readEE				;
	movwf IR_BEF_OK			;
	movlw d'79'				;Potentiometer Typ:  0 = AD5262, 1 = Eigenbau
	call readEE				;
	movwf POTI_TYP			;
	movlw d'80'				;Betriebsart Kanalwahl:  0 = Aoto, 1 = Manuell
	call readEE				;
	movwf CHA_AUTOMAN		;
	movlw d'81'				;Gespeicherte Kanalnummer
	call readEE				;
	btfss CHA_AUTOMAN,0		;prfen, ob CHA_AUTOMAN = 1
	goto $+5				;CHA_AUTOMAN >1<
	movwf CHANNEL			;CHA_AUTOMAN = 1, kopiere die gespeicherte Kanalnummer von w nach f
	movlw d'1'
	movwf CHA_AUTO			;setze das Auto/Man Statusbit Register
	goto $+4
	movlw d'1'
	movwf CHANNEL			;
	clrf CHA_AUTO			;lsche das Auto/Man Statusbit Register

	clrf CHANNEL_ALT		;Lsche Register
	clrf CH1_ALT			;
	clrf KH_ALT				;
	clrf IR_ADR				;
	clrf IR_BEF				;
	clrf IR_NEU				;

	bsf OUT_BOX				;Boxen Audio freigeben
	bcf OUT_KH				;setze Kopfhrerer Ausgang auf low = Audioausgang Boxen ist eingeschaltet
	bsf INTCON,GIE			;Erlaube Interrupts

	btfsc IN_MENU			;prfen ob Men Taste gedrckt ist
	goto main				;Taste ist nicht gedrckt, weiter zur Huptschleife
	bsf PCLATH,3			;Select Page 1
	call disp_set_poti		;Anzeige des Poti Einstellungs Men
	bcf PCLATH,3			;Select Page 0	
	nop
	btfss IN_MENU			;prfen ob Men Taste noch gedrckt ist
	goto $-1				;Taste ist noch gedrckt, weiter prfen bis Taste nicht mehr gedrckt ist
	movlw d'1'				;lade Register mit Wert 1
	movwf MENUE_FF			;
	goto menu_poti_set		;weiter bei Poti Einstellungsmen

;Testbereich Anfang

;Testbereich Ende

main							;Beginn der Hauptschleife
	btfsc MENUE_FF,0			
	goto menue_1				;springe zum Programmteil "Menue"

	bsf PCLATH,3				;Select Page 1
	btfsc DISP_NEU,0			;Prfen ob Statusbit fr Update Normalanzeige nicht gesetzt ist
	call disp_normal
	bcf PCLATH,3				;Select Page 0
	btfss IR_NEU,0				;prfen, ob Statusbit fr IR-Befehl gesetzt ist
	goto tast_abfrage			;Statusbit ist nicht gesetzt, weiter zur Auswertung der Eingabetasten
	movfw IR_ADR_1				;hole die erste, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto auswert_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	movfw IR_ADR_2				;1.Adresse war ungltig, hole die zweite, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto auswert_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	movfw IR_ADR_3				;2.Adresse war ungltig, hole die dritte, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto auswert_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	goto auswert_ir_end			;2.Adresse war ungltig, weiter bei

auswert_irbef
	movlw d'12'					;= Befehl System On/Off
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call sys_onoff				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	btfss OUT_POWER				;Prfen ob Ausgang Power gesetzt ist
	goto auswert_ir_end			;Ausgang ist nicht gesetzt (System off), Abbruch der Auswertung
	movfw IR_BEF				;prfen ob eine Zahl zwischen 0 und CHA_MAX gesendet wurde,
								;hole gesendeten IR-Befehl ins W-Register
	subwf CHA_MAX,w				;subtrahiere W von CHA_MAX
	btfss STATUS,C				;prfen ob Ergebnis negativ
	goto $+3					;Ergebnis ist negativ, d.h es wurde eine Zahl grsser CHA_MAX gesendet
	call cha_man				;Ergebnis ist positiv, d.h es wurde eine Zahl zwischen 0 und CHA_MAX gesendet
	goto auswert_ir_end
	movlw d'13'					;= Befehl Mute On/Off
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call mute_onoff				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movlw d'16'					;= Befehl Volumen +
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call vol_plus				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movlw d'17'					;= Befehl Volumen -
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call vol_minus				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movlw d'32'					;= Befehl Kanal +
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call cha_plus				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movlw d'33'					;= Befehl Kanal -
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call cha_minus				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movfw IR_BEF_BAS			;= Befehl Bass On/Off
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call bass_onoff				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
	movfw IR_BEF_MEN			;= Befehl Men On/Off
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	call menue_stat				;Ergebnis = 0, Aufruf des Unterprogramms
	goto auswert_ir_end
auswert_ir_end
	bcf IR_NEU,0				;lsche Statusbit
	bsf INTCON,INTE				;setze Interruptbit

tast_abfrage					;Programmteil zur Auswertung der Eingabetasten
	btfss IN_ONOFF				;prfen, ob Taste gedrckt ist
	call sys_onoff				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms
	btfss OUT_POWER				;Prfen ob Ausgang Power gesetzt ist
	goto main					;Ausgang ist nicht gesetzt (System off), Abbruch der Auswertung
	btfss IN_MENU				;prfen, ob Taste gedrckt ist
	call menue_stat				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms fr Menue Flip Flop
	btfss IN_VOL_P				;prfen, ob Taste gedrckt ist
	call vol_plus				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms
	btfss IN_VOL_M				;prfen, ob Taste gedrckt ist
	call vol_minus				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms
	btfss IN_CHA_P				;prfen, ob Taste gedrckt ist
	call cha_plus				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms
	btfss IN_CHA_M				;prfen, ob Taste gedrckt ist
	call cha_minus				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms
	btfss IN_OK					;prfen, ob Taste gedrckt ist
	call bass_onoff				;Taste ist gedrckt (Eingang ist low), Aufruf des Unterprogramms

channel_auto					;Programmteil zur automatischen Umschaltung der Eingnge nach Prioritt
	btfsc CHA_AUTO,0			;prfe ob Statusbit nicht gesetzt ist  (0=auto, 1=manuell)
	goto cha_auto_end			;Statusbit ist gesetzt (manuell), springe zur Programmschleife
channel_auto_8
	movlw d'8'					;Prfen ob 8 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_7			;8 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH8				;prfen ob Eingang 8 low ist
	goto channel_auto_7			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'8'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_7
	movlw d'7'					;Prfen ob 7 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_6			;7 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH7				;prfen ob Eingang 7 low ist
	goto channel_auto_6			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'7'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_6
	movlw d'6'					;Prfen ob 6 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_5			;6 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH6				;prfen ob Eingang 6 low ist
	goto channel_auto_5			;Eingang ist nicht high, weiter bei nchster Abfrage
	movlw d'6'					;Eingang ist high, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_5
	movlw d'5'					;Prfen ob 5 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_4			;5 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH5				;prfen ob Eingang 5 low ist
	goto channel_auto_4			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'5'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_4
	movlw d'4'					;Prfen ob 4 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_3			;4 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH4				;prfen ob Eingang 4 low ist
	goto channel_auto_3			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'4'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_3
	movlw d'3'					;Prfen ob 3 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_2			;3 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH3				;prfen ob Eingang 3 low ist
	goto channel_auto_2			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'3'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_2
	movlw d'2'					;Prfen ob 2 > CHA_MAX
	subwf CHA_MAX,w
	btfss STATUS,C
	goto channel_auto_1			;2 > CHA_MAX, weiter zur nchsten Prfung
	btfsc IN_CH2				;prfen ob Eingang 2 low ist
	goto channel_auto_1			;Eingang ist nicht low, weiter bei nchster Abfrage
	movlw d'2'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
	goto cha_auto_end			;springe an das Ende des Programmteils
channel_auto_1
	movlw d'1'					;Eingang ist low, kopiere die Eingangsnummer ins CHANNEL Register
	movwf CHANNEL				;
cha_auto_end
	btfsc CHA_AUTO,1			;prfe ob sich der Status manuell/auto gendert hat (Bit 1)
	goto $+3					;Status ist unverndert
	bsf CHA_AUTO,1				;
	bsf DISP_NEU,0
	movfw CHANNEL_ALT			;Prfen ob sich die Kanalnummer gendert hat
	subwf CHANNEL,w
	btfss STATUS,Z
	call cha_set				;Aufruf des Unterprogramms zum setzen der Ausgnge, Volumen und Displaydaten

kopfhoerer						;Programmteil fr Abschaltung Boxen bei Kopfhrerbetrieb
	btfss IN_KH					;prfen ob Schaltkontakt Kopfhrer high ist (Kopfhrer eingesteckt)
	goto kopfhoerer_off			;kein Kopfhrer eingesteckt, weiter bei $+4
	btfsc KH_ALT,0				;prfen ob Bit fr Kopfhrerbetrieb nicht gesetzt ist
	goto vol_m_clip				;Bit ist gesetzt, d.h keine nderung
	bsf KH_ALT,0				;Bit ist nicht gesetzt, setze Bit 
	bsf OUT_KH					;Kopfhrer eingesteckt,setze Kopfhrerer Ausgang auf high = Audioausgang Boxen ist abgeschaltet
	bcf OUT_BOX					;Boxen Audio auf Standby
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	goto vol_m_clip				;weiter in der Hauptschleife
kopfhoerer_off
	btfss KH_ALT,0				;prfen ob Bit fr Kopfhrerbetrieb gesetzt ist
	goto vol_m_clip				;Bit ist nicht gesetzt, d.h keine nderung, weiter in der Hauptschleife
	clrf KH_ALT					;Bit ist gesetzt, Lsche Register
	bcf OUT_KH					;setze Kopfhrerer Ausgang auf low = Audioausgang Boxen ist eingeschaltet
	bsf OUT_BOX					;Boxen Audio freigeben
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige

vol_m_clip						;Programmteil zur reduzierung der Lautstrke, wenn Boxen berlastet sind
	btfsc IN_CLIP				;prfen ob keine berlast detektiert wurde (Eingang low)
	call vol_minus				;Es wurde berlast detektiert (Eingang high), Aufruf des Unterprogramms zur Vol Reduzierung

auto_onoff						;Programmteil zur Prfung des Mastereingangs 1 auf positive Flanke (Abschaltung)
	btfsc CHA_AUTOMAN,0			;prfen, ob Betriebsart Auto fr die Kanle eingestellt ist
	goto main					;Betriebsart Manuell ist eingestellt, zurck zur Schleife
	btfsc IN_CH1				;Prfen ob Eingang low ist (eingeschaltet)
	goto $+3					;Eingang ist high (ausgeschaltet), vergleiche mit altem Zustand
	bsf CH1_ALT,0				;Eingang ist low (eingeschaltet), setze On-Bit
	goto main					;weiter in der Hauptprogrammschleife
	btfss CH1_ALT,0				;prfe alten Zustand 
	goto main					;weiter in der Hauptprogrammschleife
	bcf CH1_ALT,0				;positive Flanke, lsche On-Bit	
	call sys_onoff				;
	goto main

menue_1						;Programmverzweigung fr Mensteuerung
	call menu_befehl		;Aufruf des Unterprogramms zum laden der Tastatur- bzw. IR-Befehle
	bsf PCLATH,3			;Select Page 1
	btfsc DISP_NEU,4
	call disp_menue_1
	bcf PCLATH,3			;Select Page 0
	btfsc BEFEHL,1			;Prfen ob Bit fr Befehl Men nicht gesetzt ist
	call menue_stat			;Bit ist gesetzt, Aufruf des Unterprogramms
	btfss MENUE_FF,0		;Prfen ob Bit fr Men Ein gesetzt ist			
	goto main				;Bit ist nicht gesetzt, springe zur Hauptschleife
	btfsc BEFEHL,3			;Prfen ob Bit fr Befehl "up" nicht gesetzt ist
	call menue_1up			;Bit ist gesetzt, Aufruf des Unterprogramms
	btfsc BEFEHL,4			;Prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call menue_1dn			;Bit ist gesetzt, Aufruf des Unterprogramms

	btfss BEFEHL,2			;Prfen ob Bit fr Befehl OK gesetzt ist
	goto menue_1			;Bit ist nicht gesetzt, zurck zur Menschleife
	movfw MENUE_COUNT
	movwf MENUE_1_CNT

	bsf PCLATH,3			;Select Page 1
	call clear_display		;Aufruf des Unterprogramms zum Lschen des Displays
	bcf PCLATH,3			;Select Page 0

	movlw d'1'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_startvol_set	; Aufruf des Programmteils menu_startvol_set
	movlw d'2'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_automan_set	; Aufruf des Programmteils menu_automan_set
	movlw d'3'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_kanalname_set	; Aufruf des Programmteils menu_kanalname_set
	movlw d'4'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_kanalzahl_set	; Aufruf des Programmteils menu_kanalzahl_set
	movlw d'5'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_irtest_set	; Aufruf des Programmteils menu_irtest_set
	movlw d'6'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_iradr_set	; Aufruf des Programmteils menu_iradr_set
	movlw d'7'				;
	subwf MENUE_1_CNT, w	;
	btfsc STATUS, Z		
	goto menu_irbef_set	; Aufruf des Programmteils menu_irbef_set
	goto main

menu_startvol_set			;Menpunkt 1
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	movlw d'2'				;Anzeige hat 2 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	movfw CHANNEL			;sichern des aktuellen Kanals in Temp Register
	movwf TEMP_10
	movfw VOLUME			;sichern des aktuellen Volumens in Temp Register
	movwf TEMP_11
	movlw 0x01				;lade Kanal Register mit Wert 1
	movwf CHANNEL
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_startvol
	call dig_startvol1		;
	bcf PCLATH,3			;Select Page 0
loop_startvol_set
	call menu_befehl		;Aufruf Unterprogramm zum Laden der Tastaturbefehle
	btfsc BEFEHL,1			;prfen ob Bit fr Befehl Menue nicht gesetzt ist
	goto copy_startvol1		;wenn ja berspringe diesen Befehl, wenn nein Rcksprung in die Hauptschleife	
	btfsc BEFEHL,2			;prfen ob Bit fr Befehl OK nicht gesetzt ist
	goto copy_startvol		;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,5			;prfen ob Bit fr Befehl "right" nicht gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,6			;prfen ob Bit fr Befehl "left" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_startvol1		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	btfss BEFEHL,3			;prfen ob Bit fr Befehl "up" gesetzt ist
	goto $+4				;Bit ist nicht gesetzt, weiter bei nchster Prfung
	bsf TEMP_DIG_STAT,1		;setze Statusbit fr "up"
	bsf PCLATH,3			;Select Page 1
	call dig_startvol1		;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc BEFEHL,4			;prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call dig_startvol1		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_startvol_set	;zurck zur Schleife 

copy_startvol				;Schreibe Volumen ins EEPROM
	movfw VOLUME			;kopiere das Volumen in das Temp Schreibregister fr das EEPROM
	movwf TEMP_13
	movfw CHANNEL			;hole den Kanal ins W-Register und reduziere um 1 (+255 => -1)
	addlw 0xFF
	call writeEE
	movlw d'250'			;Wartezeit von 250ms, damit der Schreibvorgang vor
	movwf LOOP_1			;  dem nchsten Lesevorgang beendet werden kann
	call wait 			
copy_startvol1
	movfw TEMP_10			;Rcksichern des aktuellen Kanals ins CHANNEL Register
	movwf CHANNEL
	call read_channel		;Aufruf des Unterprogramms zum lesen des Kanalnamens aus dem EEPROM
	movfw TEMP_11			;Rcksichern des aktuellen Volumens ins VOLUME Register
	movwf VOLUME
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_automan_set			;Menpunkt 2:
	movfw CHA_AUTOMAN		;kopieren der aktuellen Betriebsart fr Kanalwahl ins Temp Register
	movwf TEMP_10
	movwf TEMP_DIG_CNT
	incf TEMP_DIG_CNT
	movlw d'2'				;Anzeige hat 2 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_automan
	call dig_automan1		;
	bcf PCLATH,3			;Select Page 0
loop_automan_set
	call menu_befehl		;Aufruf Unterprogramm zum Laden der Tastaturbefehle
	btfsc BEFEHL,1			;prfen ob Bit fr Befehl Menue nicht gesetzt ist
	goto copy_automan1		;wenn ja berspringe diesen Befehl, wenn nein Rcksprung in die Hauptschleife	
	btfsc BEFEHL,2			;prfen ob Bit fr Befehl OK nicht gesetzt ist
	goto copy_automan		;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,5			;prfen ob Bit fr Befehl "right" nicht gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,6			;prfen ob Bit fr Befehl "left" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,3			;prfen ob Bit fr Befehl "up" gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,4			;prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_automan1		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_automan_set	;zurck zur Schleife 

copy_automan
	movfw TEMP_10			;kopieren des Poti Typs aus dem Temp Register ins Befehlsregister und speichern im EEPROM
	movwf CHA_AUTOMAN		;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'80'				;EEPROM Adresse
	call writeEE
	movlw d'1'				;lade Wert 1 in Channel Register
	movwf CHANNEL
copy_automan1
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main


menu_kanalname_set			;Menpunkt 3
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	movlw d'9'				;Anzeige hat 9 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	movfw CHANNEL			;sichern des aktuellen Kanals in Temp Register
	movwf TEMP_10
	movfw VOLUME			;sichern des aktuellen Volumens in Temp Register
	movwf TEMP_11
	movlw 0x01				;lade Kanal Register mit Wert 1
	movwf CHANNEL
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_name
	call dig_name1			;
	bcf PCLATH,3			;Select Page 0
loop_name_set
	call menu_befehl		;Aufruf Unterprogramm zum Laden der Tastaturbefehle
	btfsc BEFEHL,1			;prfen ob Bit fr Befehl Menue nicht gesetzt ist
	goto copy_name1			;wenn ja berspringe diesen Befehl, wenn nein Rcksprung in die Hauptschleife	
	btfsc BEFEHL,2			;prfen ob Bit fr Befehl OK nicht gesetzt ist
	goto copy_name			;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,5			;prfen ob Bit fr Befehl "right" nicht gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,6			;prfen ob Bit fr Befehl "left" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_name1			;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	btfss BEFEHL,3			;prfen ob Bit fr Befehl "up" gesetzt ist
	goto $+4				;Bit ist nicht gesetzt, weiter bei nchster Prfung
	bsf TEMP_DIG_STAT,1		;setze Statusbit fr "up"
	bsf PCLATH,3			;Select Page 1
	call dig_name1			;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc BEFEHL,4			;prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call dig_name1			;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_name_set		;zurck zur Schleife 

copy_name					;Schreibe Temp Volumen ins EEPROM
	movfw TEXT_DIG1			;Kopiere TEXT_DIG ins EEPROM Schreibregister
	movwf TEMP_13
	movfw CHANNEL			;kopiere die Kanalnr. ins TEMP_12 Register, dieses wird als Adressregister verwendet
	movwf TEMP_12			;
	bcf STATUS,C			;Lsche Carry Bit, damit es beim rotieren nicht strt
	rlf TEMP_12				;die Kanalnr. in TEMP_13 wird 3x nach links geschoben (mit 8 multipliziert), 
	rlf TEMP_12				;dieses ergibt die EEPROM Adresse fr das erste Text DIGIT
	rlf TEMP_12				;
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG2			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG3			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG4			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG5			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG6			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG7			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE
	movfw TEXT_DIG8			;Kopiere TEXT_DIG ins TEMP_13 Register, dieses wird als EEPROM Schreibregister verwendet
	movwf TEMP_13
	incf TEMP_12			;Erhhe die Adresse um 1
	movfw TEMP_12			;hole die EEPROM Adresse ins W-Register und schreibe den Wert aus TEMP_13 ins EEPROM
	call writeEE

	movlw d'250'			;Wartezeit von 250ms, damit der Schreibvorgang vor
	movwf LOOP_1			;  dem nchsten Lesevorgang beendet werden kann
	call wait 			
copy_name1
	movfw TEMP_10			;Rcksichern des aktuellen Kanals ins CHANNEL Register
	movwf CHANNEL
	call read_channel		;Aufruf des Unterprogramms zum lesen des Kanalnamens aus dem EEPROM
	movfw TEMP_11			;Rcksichern des aktuellen Volumens ins VOLUME Register
	movwf VOLUME
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_kanalzahl_set			;Menpunkt 4: Setzen der Kanalanzahl, die abgefragt werden sollen (max 8)
	movfw CHA_MAX			;kopiere Kanalanzahl Register in Temp Register
	movwf TEMP_DIG_VAL
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_kanalzahl
	call dig_kanalzahl		;
	bcf PCLATH,3			;Select Page 0
loop_kanalzahl_set
	call menu_befehl		;Aufruf Unterprogramm zum Laden der Tastaturbefehle
	btfsc BEFEHL,1			;prfen ob Bit fr Befehl Menue nicht gesetzt ist
	goto copy_kanalzahl1	;wenn ja berspringe diesen Befehl, wenn nein Rcksprung in die Hauptschleife	
	btfsc BEFEHL,2			;prfen ob Bit fr Befehl OK nicht gesetzt ist
	goto copy_kanalzahl		;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc BEFEHL,3			;prfen ob Bit fr Befehl "up" nicht gesetzt ist
	call dig_kanalzahl		;Bit ist nicht gesetzt, weiter bei nchster Prfung
	bsf PCLATH,3			;Select Page 1
	btfsc BEFEHL,4			;prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call dig_kanalzahl		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_kanalzahl_set	;zurck zur Schleife 

copy_kanalzahl				;Schreibe Temp Volumen ins EEPROM
	movfw TEMP_DIG_VAL			;kopiere das Temp Volumen in das Temp Schreibregister fr das EEPROM
	movwf TEMP_13
	movlw d'72'				;EEPROM Adresse
	call writeEE
	movlw d'250'			;Wartezeit von 250ms, damit der Schreibvorgang vor
	movwf LOOP_1			;  dem nchsten Lesevorgang beendet werden kann
	call wait 			
copy_kanalzahl1
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_irtest_set				;Menpunkt 5: In diesem Programmteil werden die RC5 IR-Adresse und IR-Befehle angezeigt
	bsf PCLATH,3			;Select Page 1
	call disp_set_irtest
	bcf PCLATH,3			;Select Page 0
loop_irtest_set
	bsf PCLATH,3			;Select Page 1
	btfsc IR_NEU,0			;prfen, ob Statusbit fr IR-Befehl nicht gesetzt ist
	call disp_set_irtest	;Bit ist gesetzt, Aufruf des Unterprogramms
	btfsc IR_BIT,2			;prfen ob das IR Fehlerbit gesetzt ist
	call disp_set_irtest	;Bit ist gesetzt, Aufruf des Unterprogramms
	bcf PCLATH,3			;Select Page 0
	btfss IN_MENU			;prfen ob Men Taste nicht gedrckt ist (high ist)
	goto copy_irtest		;Taste ist gedrckt, gehe zum Ende des Programmteiles
	btfss IN_OK				;prfen ob OK Taste nicht gedrckt ist (high ist)
	goto copy_irtest		;Taste ist gedrckt, gehe zum Ende des Programmteiles
	goto loop_irtest_set	
copy_irtest
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_iradr_set				;Menpunkt 6: Setzen der RC5 IR-Adressen
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	movlw d'3'				;Anzeige hat 3 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	movfw IR_ADR_1			;kopieren der 1.RC5-Adresse ins Temp Register
	movwf TEMP_10
	movfw IR_ADR_2			;kopieren der 2.RC5-Adresse ins Temp Register
	movwf TEMP_11
	movfw IR_ADR_3			;kopieren der 3.RC5-Adresse ins Temp Register
	movwf TEMP_12
	movlw d'32'				;kopiere Maximalwert+1 fr RC5-Adresse in Temp Register
	movwf TEMP_18	
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_iradr
	call dig_iradrbef		;
	bcf PCLATH,3			;Select Page 0
loop_iradr_set
	btfss IN_MENU			;prfen ob Taster fr Befehl Menue nicht gedrckt ist
	goto copy_iradr1		;Taste ist gedrckt, Rcksprung in die Hauptschleife	
	btfss IN_OK				;prfen ob Taster fr Befehl OK nicht gedrckt ist
	goto copy_iradr			;Taste ist gedrckt, gehe zum Ende des Programmteils
	btfss IN_CHA_P			;prfen ob Taster fr Befehl "right" nicht gedrckt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfss IN_CHA_M			;prfen ob Taster fr Befehl "left" nicht gedrckt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	btfsc IN_VOL_P			;prfen ob Taster fr Befehl "up" gedrckt ist
	goto $+4				;Taster ist nicht gedrckt, weiter bei nchster Prfung
	bsf TEMP_DIG_STAT,1		;setze Statusbit fr "up"
	bsf PCLATH,3			;Select Page 1
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfss IN_VOL_M			;prfen ob Taster fr Befehl "down" nicht gedrckt ist
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_iradr_set		;zurck zur Schleife
copy_iradr
	movfw TEMP_10			;kopieren der 1.RC5-Adresse aus dem Temp Register ins Adressregister und speichern im EEPROM
	movwf IR_ADR_1			;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'73'				;EEPROM Adresse
	call writeEE
	movfw TEMP_11			;kopieren der 2.RC5-Adresse aus dem Temp Register ins Adressregister und speichern im EEPROM
	movwf IR_ADR_2			;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'74'				;EEPROM Adresse
	call writeEE
	movfw TEMP_12			;kopieren der 3.RC5-Adresse aus dem Temp Register ins Adressregister und speichern im EEPROM
	movwf IR_ADR_3			;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'75'				;EEPROM Adresse
	call writeEE
copy_iradr1
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_irbef_set				;Menpunkt 7: Setzen der RC5 IR-Befehle fr Bass, Men, OK
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	movlw d'3'				;Anzeige hat 3 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	movfw IR_BEF_MEN		;kopieren des RC5-Befehls Men ins Temp Register
	movwf TEMP_10
	movfw IR_BEF_OK			;kopieren des RC5-Befehls OK ins Temp Register
	movwf TEMP_11
	movfw IR_BEF_BAS		;kopieren des RC5-Befehls Bassanhebung ins Temp Register
	movwf TEMP_12
	movlw d'64'				;kopiere Maximalwert+1 fr RC5-Adresse in Temp Register
	movwf TEMP_18	
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_irbef
	call dig_iradrbef		;
	bcf PCLATH,3			;Select Page 0
loop_irbef_set
	btfss IN_MENU			;prfen ob Taster fr Befehl Menue nicht gedrckt ist
	goto copy_irbef1		;Taste ist gedrckt, Rcksprung in die Hauptschleife	
	btfss IN_OK				;prfen ob Taster fr Befehl OK nicht gedrckt ist
	goto copy_irbef			;Taste ist gedrckt, gehe zum Ende des Programmteils
	btfss IN_CHA_P			;prfen ob Taster fr Befehl "right" nicht gedrckt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfss IN_CHA_M			;prfen ob Taster fr Befehl "left" nicht gedrckt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	btfsc IN_VOL_P			;prfen ob Taster fr Befehl "up" gedrckt ist
	goto $+4				;Taster ist nicht gedrckt, weiter bei nchster Prfung
	bsf TEMP_DIG_STAT,1		;setze Statusbit fr "up"
	bsf PCLATH,3			;Select Page 1
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfss IN_VOL_M			;prfen ob Taster fr Befehl "down" nicht gedrckt ist
	call dig_iradrbef		;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_irbef_set		;zurck zur Schleife
copy_irbef
	movfw TEMP_10			;kopieren des RC5-Befehl Men aus dem Temp Register ins Befehlsregister und speichern im EEPROM
	movwf IR_BEF_MEN		;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'77'				;EEPROM Adresse
	call writeEE
	movfw TEMP_11			;kopieren des RC5-Befehl OK aus dem Temp Register ins Befehlsregister und speichern im EEPROM
	movwf IR_BEF_OK			;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'78'				;EEPROM Adresse
	call writeEE
	movfw TEMP_12			;kopieren des RC5-Befehl Bassanhebung aus dem Temp Register ins Befehlsregister und speichern im EEPROM
	movwf IR_BEF_BAS		;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'76'				;EEPROM Adresse
	call writeEE
copy_irbef1
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main

menu_poti_set				;Wahl des verwendeten Potis, Aufruf wenn Men Taste beim Einschalten gedrckt ist
	movfw POTI_TYP			;kopieren des aktuellen Poti Typs ins Temp Register
	movwf TEMP_10
	movwf TEMP_DIG_CNT
	incf TEMP_DIG_CNT
	movlw d'2'				;Anzeige hat 2 Stellen, die gesetzt werden
	movwf TEMP_CNT_MAX		;
	bsf TEMP_DIG_STAT,0		;setze Statusbit
	bsf PCLATH,3			;Select Page 1
	call cursor_on			;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_set_poti
	call dig_poti1			;
	bcf PCLATH,3			;Select Page 0
loop_poti_set
	call menu_befehl		;Aufruf Unterprogramm zum Laden der Tastaturbefehle
	btfsc BEFEHL,1			;prfen ob Bit fr Befehl Menue nicht gesetzt ist
	goto copy_poti1	 		;wenn ja berspringe diesen Befehl, wenn nein Rcksprung in die Hauptschleife	
	btfsc BEFEHL,2			;prfen ob Bit fr Befehl OK nicht gesetzt ist
	goto copy_poti			;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,5			;prfen ob Bit fr Befehl "right" nicht gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,6			;prfen ob Bit fr Befehl "left" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,3			;prfen ob Bit fr Befehl "up" gesetzt ist
	call inc_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	btfsc BEFEHL,4			;prfen ob Bit fr Befehl "down" nicht gesetzt ist
	call dec_dig_temp_cnt	;wenn ja berspringe diesen Befehl
	bsf PCLATH,3			;Select Page 1
	btfsc TEMP_DIG_STAT,0	;prfen ob bit in register nicht gesetzt ist
	call dig_poti1			;wenn ja berspringe diesen Befehl
	bcf PCLATH,3			;Select Page 0
	goto loop_poti_set		;zurck zur Schleife 

copy_poti
	movfw TEMP_10			;kopieren des Poti Typs aus dem Temp Register ins Befehlsregister und speichern im EEPROM
	movwf POTI_TYP			;
	movwf TEMP_13			;zu speichernder Wert
	movlw d'79'				;EEPROM Adresse
	call writeEE
copy_poti1
	bsf DISP_NEU,0			;setze Statusbit fr Update Display
	movlw d'1'				;Rcksetzen des Zhlers auf 1
	movwf TEMP_DIG_CNT
	call menue_stat			;
	goto main


;*******************************************************************************************
; Unterprogramme
;*******************************************************************************************


menu_befehl						;Unterprogramm zum Laden und invertieren der Tastatur- und IR-Befehle 
	movlw 0xFF					;lade Register Befehl mit Wert 255
	movwf BEFEHL
	movfw PORTB					;hole PORTB ins W-Register und subtrahiere es von 255 im Register Befehl
	subwf BEFEHL				;255-PORTB=BEFEHL

	btfss IR_NEU,0				;prfen, ob Statusbit fr neuen IR-Befehl gesetzt ist
	return						;Statusbit ist nicht gesetzt, Rcksprung aus dem Unterprogramm

	movfw IR_ADR_1				;hole die erste, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto menu_aw_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	movfw IR_ADR_2				;1.Adresse war ungltig, hole die zweite, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto menu_aw_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	movfw IR_ADR_3				;2.Adresse war ungltig, hole die dritte, fr die Auswertung gltige Adresse ins W-Register
	subwf IR_ADR,w				;subtrahiere die empfangene Adresse
	btfsc STATUS,Z				;prfen ob Ergebnis >0<
	goto menu_aw_irbef			;Ergebnis = 0 (Adresse ist gltig), weiter bei Auswertung des Befehls
	goto menu_befehl_end		;3.Adresse war ungltig, weiter bei Ende des Unterprogramms
menu_aw_irbef
	movfw IR_BEF_MEN			;= Befehl Men On/Off
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,1				;Ergebnis = 0, setze Bit fr Men
	goto menu_befehl_end
	movfw IR_BEF_OK				;= Befehl OK
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,2				;Ergebnis = 0, setze Bit fr OK
	goto menu_befehl_end
	movlw d'16'					;= Befehl Volumen + => im Men "up"
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,3				;Ergebnis = 0, setze Bit fr "up"
	goto menu_befehl_end
	movlw d'17'					;= Befehl Volumen - => im Men "down"
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,4				;Ergebnis = 0, setze Bit fr "down"
	goto menu_befehl_end
	movlw d'32'					;= Befehl Kanal + => im Men "right"
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,5				;Ergebnis = 0, setze Bit fr "right"
	goto menu_befehl_end
	movlw d'33'					;= Befehl Kanal - => im Men "left"
	subwf IR_BEF,w				;subtrahiere den empfangenen IR-Befehl
	btfss STATUS,Z				;prfen ob Ergebnis 0
	goto $+3					;Ergebnis >0<, weiter bei nchster Prfung
	bsf BEFEHL,6				;Ergebnis = 0, setze Bit fr "left"
	goto menu_befehl_end
menu_befehl_end
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	bcf IR_NEU,0				;lsche Statusbit
	bsf INTCON,INTE				;setze Interruptbit
	return

menue_1up					;Programmteil zum Erhhen des Menpunktes
	bsf DISP_NEU,4			;setze das Statusbit
	incf MENUE_COUNT		;
	movlw d'8'
	subwf MENUE_COUNT, w
	btfss STATUS, Z		
	goto $+3
	movlw d'1'				;Rcksetzen des Zhlers mit Wert 1
	movwf MENUE_COUNT
	movlw d'1'				;lade Zhler mit Wert 1
	movwf TEMP_DIG_CNT		;
	bsf TEMP_DIG_STAT,0		;setze Statusbit fr update Cursorposition in Menpunkten Goto, Position und Speed
	movlw d'250'			;Wartezeit von 250ms
	movwf LOOP_1			;
	call wait 
	return

menue_1dn					;Programmteil zum Reduzieren des Menpunktes
	bsf DISP_NEU,4			;setze das Statusbit
	decfsz MENUE_COUNT		;
	goto $+3
	movlw d'7'				;Rcksetzen des Zhlers mit Wert 7 (7 Menpunkte)
	movwf MENUE_COUNT
	movlw d'1'				;lade Zhler mit Wert 1
	movwf TEMP_DIG_CNT		;
	bsf TEMP_DIG_STAT,0		;setze Statusbit fr update Cursorposition in Menpunkten Goto, Position und Speed
	movlw d'250'			;Wartezeit von 250ms
	movwf LOOP_1			;
	call wait 
	return
	

vol_plus
	bsf OUT_SHD_VOL				;setze Ausgang Shut Down Volume auf high => Mute off
	movlw d'32'					;prfen ob Volume schon den Maximalwert erreicht hat
	subwf VOLUME,w
	btfsc STATUS,Z
	goto vol_end
	incf VOLUME
	goto vol_end
vol_minus
	movfw VOLUME
	btfsc STATUS,Z
	goto vol_end
	decfsz VOLUME
	goto vol_end
	bcf OUT_SHD_VOL				;setze Ausgang Shut Down Volume auf low => Mute on
vol_end
	movfw POTI_TYP				;prfen welches Poti installiert ist
	btfss STATUS,Z				;
	goto vol_end1				;Poti Typ 1 (Eigenbau) ist gewhlt, weiter bei vol_end1
		
	movlw 0x07					;Poti Typ 0 (AD5262) ist gewhlt, weiter in der Routine
	movwf PCLATH				;vorbereiten fuer Vol-Tabelle im Bereich 0x700..0x7ff
	movfw VOLUME
	call volume_tab				;hole wert aus volumentabelle
	movwf VOL_BIN				;sichern des W-Registers im VOL_BIN Register
	clrf PCLATH
	call volume_change			;senden des Wertes an Volumecontroller AD5262
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	return
vol_end1						;Unterprogramm fr Poti Typ 1 (Eigenbau) 
	movfw VOLUME
	movwf VOL_BIN				;sichern des Volumens im VOL_BIN Register
	movfw VOL_BIN
	btfss STATUS,Z
	decf VOL_BIN				;
	bcf OUT_CS_VOL
	movfw VOL_BIN
	call vol_routine
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	return


cha_man
	bsf CHA_AUTO,0				;setze das Statusbit fr manuelle Kanaleinstellung
	btfsc CHA_AUTOMAN,0			;Prfe ob Kanaleinstellung = auto
	goto $+4					;Kanaleinstellung = manuell
	movfw IR_BEF				;Kanaleinstellung = auto, kopiere den gesendeten IR Befehl ins CHANNEL Register
	movwf CHANNEL				;Kopiere den Befehl ins CHANNEL Register
	goto cha_set				;weiter zum setzen der Eingnge
	movfw IR_BEF				;Kanaleinstellung = manuell, hole den gesendeten IR Befehl ins W-Register
	btfss STATUS,Z				;  und prfe ob 0
	movwf CHANNEL				;IR Befehl ist nicht 0, Kopiere den Befehl ins CHANNEL Register
	goto cha_set				;IR Befehl ist 0, weiter zum setzen der Eingnge	
cha_plus
	bsf CHA_AUTO,0				;setze das Statusbit fr manuelle Kanaleinstellung
	movfw CHA_MAX				;prfen, ob Maximalwert erreicht ist
	subwf CHANNEL,w
	btfsc STATUS,Z
	goto $+3					;Maximalwert ist erreicht
	incf CHANNEL				;Maximalwert ist nicht erreicht, erhhe Kanalnummer
	goto cha_set
	movfw CHA_AUTOMAN			;Maximalwert ist erreicht, rcksetzen des Zhlers mit 0 oder 1, abhngig von Betriebsart
	movwf CHANNEL
	goto cha_set
cha_minus
	bsf CHA_AUTO,0				;setze das Statusbit fr manuelle Kanaleinstellung
	movfw CHA_AUTOMAN			;prfen ob Minimalwert (0 oder 1, abhngig von Betriebsart) erreicht ist
	subwf CHANNEL,w
	btfsc STATUS,Z
	goto $+3					;Minimalwert ist erreicht
	decf CHANNEL				;Minimalwert ist nicht erreicht, reduziere Kanalnummer
	goto cha_set
	movfw CHA_MAX				;Minimalwert ist erreicht, rcksetzen des Zhlers mit Maximalwert
	movwf CHANNEL
cha_set
	movfw CHANNEL				;hole den Kanal ins W-Register und prfe ob 0
	btfss STATUS,Z				;
	goto $+4					;Kanal ist nicht 0, weiter bei Auswertung
	movfw CHA_AUTOMAN			;Kanal ist 0, setze oder lsche das Auto/Man Statusbit, je nach Betriebsart
	movwf CHA_AUTO				;
	goto cha_end

	bcf OUT_SHD_VOL				;setze Ausgang Shut Down Volume auf low => Mute on
	movfw CHANNEL				;Kopiere Kanalnummer ins temporre Register (Kanal 1-8)
	movwf TEMP_10				;
	decf TEMP_10				;Reduziere temporres Register um 1 (Umwandlung Kanal 1-8 in Adresse 0-7)
	btfss TEMP_10,0				;Prfe ob Bit0 = 1
	bcf OUT_CHDB0				;Bit0 = 0 => setze Ausgang OUT_CHDB0 auf low
	btfsc TEMP_10,0				;Prfe ob Bit0 = 0
	bsf OUT_CHDB0				;Bit0 = 1 => setze Ausgang OUT_CHDB0 auf high
	btfss TEMP_10,1				;Prfe ob Bit1 = 1
	bcf OUT_CHDB1				;Bit1 = 0 => setze Ausgang OUT_CHDB1 auf low
	btfsc TEMP_10,1				;Prfe ob Bit1 = 0
	bsf OUT_CHDB1				;Bit1 = 1 => setze Ausgang OUT_CHDB1 auf high
	btfss TEMP_10,2				;Prfe ob Bit2 = 1
	bcf OUT_CHDB2				;Bit2 = 0 => setze Ausgang OUT_CHDB2 auf low
	btfsc TEMP_10,2				;Prfe ob Bit2 = 0
	bsf OUT_CHDB2				;Bit2 = 1 => setze Ausgang OUT_CHDB2 auf high

	movfw CHANNEL_ALT			;Prfen, ob sich die Kanalnummer gendert hat
	subwf CHANNEL,w
	btfsc STATUS,Z
	goto cha_end				;Kanalnummer ist unverndert, weiter bei cha_end
	movfw CHANNEL				;Kanalnummer hat sich gendert, kopiere die aktuelle Kanalnummer ins Alt Register
	movwf CHANNEL_ALT
	call read_channel			;Aufruf des Unterprogramms zum Lesen der aktuellen Kanaldaten
	call vol_end				;Aufruf des Unterprogramms zum Einstellen des Volumens fr den aktuellen Kanal
cha_end
	bsf OUT_SHD_VOL				;setze Ausgang Shut Down Volume auf high => Mute off
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	return

sys_onoff
	btfss OUT_POWER				;prfen ob Ausgang gesetzt ist
	goto start					;Ausgang ist nicht gesetzt, starte das System
	bcf OUT_BOX					;Ausgang ist gesetzt, System ausschalten: Boxen gehen in Mute/Standby
	clrf PORTA					;Lsche alle Ausgnge von PORTA und PORTE
	clrf PORTE					;
	btfss CHA_AUTOMAN,0			;prfen, ob Betriebsart Manuell fr die Kanle eingestellt ist
	goto $+5					;Betriebsart Auto ist eingestellt, weiter in der Abschaltroutine 
	movfw CHANNEL				;Betriebsart Manuell ist eingestellt, speichern des aktuellen Kanals im EEPROM
	movwf TEMP_13				;zu speichernder Wert
	movlw d'81'					;EEPROM Adresse
	call writeEE
	bsf PCLATH,3				;Select Page 1
	call clear_display			;Aufruf des Unterprogramms zum lschen des Displays
	bcf PCLATH,3				;Select Page 0
	movlw d'100'				;Wartezeit von 100ms
	movwf LOOP_1				;
	call wait					;
	bcf OUT_POWER				;Abschalten der Versorgungsspannung fr die Boxen
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait					;
	return

mute_onoff
	btfss OUT_SHD_VOL			;prfen ob Ausgang gesetzt ist
	goto $+3
	bcf OUT_SHD_VOL				;Ausgang war gesetzt, lsche Ausgang
	goto $+2
	bsf OUT_SHD_VOL				;Ausgang war nicht gesetzt, setze Ausgang
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	return

bass_onoff
	btfss OUT_BASS				;prfen ob Ausgang gesetzt ist
	goto $+3
	bcf OUT_BASS				;Ausgang war gesetzt, lsche Ausgang
	goto $+2
	bsf OUT_BASS				;Ausgang war nicht gesetzt, setze Ausgang
	bsf DISP_NEU,0				;setze Statusbit fr Update Display, Normalanzeige
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait
	return



ir_startbit
	clrf IR_BIT				;lsche IR-Bit
	clrf IR_TEMP			;Lsche IR_TEMP Register, dieses wird als temporres Register zur Zwischenspeicherung des IR-Bits verwendet
							;2.Hlfte
	movlw d'1'				;440us Zeitverzgerung bis zur ersten Abtastung = 1 x 256us, Rest = 184us
	movwf LOOP_1			;
	movlw d'184'			;Rest = 184us 
	call wait_us			;
	btfsc IN_IR				;prfen ob IR-Eingangssignal low ist
	goto fehler				;

startbit2
	movlw d'1'				;1 Bit soll ausgewertet werden
	movwf COUNTER
	call ir_routine			;Aufruf des Unterprogramms
	btfsc IR_BIT,2			;prfen ob das Fehlerbit gesetzt ist
	goto fehler				;Fehlerbit ist gesetzt => weiter bei Fehler
	movfw IR_TEMP			;Sichern des Bits im Register IR_START2
	movwf IR_START2	

steuerbit
	movlw d'1'				;1 Bit soll ausgewertet werden
	movwf COUNTER
	call ir_routine			;Aufruf des Unterprogramms
	btfsc IR_BIT,2			;prfen ob das Fehlerbit gesetzt ist
	goto fehler				;Fehlerbit ist gesetzt => weiter bei Fehler
	movfw IR_TEMP			;Sichern des Bits im Register IR_STRG
	movwf IR_STRG

adressbits
	movlw d'5'				;5 Bit soll ausgewertet werden
	movwf COUNTER
	call ir_routine			;Aufruf des Unterprogramms
	btfsc IR_BIT,2			;prfen ob das Fehlerbit gesetzt ist
	goto fehler				;Fehlerbit ist gesetzt => weiter bei Fehler
	movfw IR_TEMP			;Sichern des Bits im Register IR_ADR
	movwf IR_ADR

befehlsbits
	movlw d'6'				;6 Bit soll ausgewertet werden
	movwf COUNTER
	call ir_routine			;Aufruf des Unterprogramms
	btfsc IR_BIT,2			;prfen ob das Fehlerbit gesetzt ist
	goto fehler				;Fehlerbit ist gesetzt => weiter bei Fehler
	movfw IR_TEMP			;Sichern des Bits im Register IR_BEF
	movwf IR_BEF

	movlw d'3'				;Zeitverzgerung von 1/2 Bit damit die 2.Hlfte des letzten Bits nicht doppelt gezhlt wird
	movwf LOOP_1			;875us = 3 x 256us, Rest = 107us
	movlw d'107'			;Rest = 107us 
	call wait_us
	
	bsf IR_NEU,0			;setze Statusbit fr IR-Befehl
	bcf INTCON,INTE			;lsche Interruptbit
	return					;Rcksprung aus dem Unterprogramm

fehler
	movlw d'30'				;Wartezeit von 30ms nach einem Fehler
	movwf LOOP_1			;
	call wait 		
	movlw 0xFF				;Bei Fehler werden die Adress- und Befehlsregister mit Wert 255 beschrieben
	movwf IR_ADR
	movwf IR_BEF
	return					;Rcksprung aus dem Unterprogramm

;==================================
;  Unterprogramme fr IR-Auswertung
;==================================

ir_routine
	clrf IR_TEMP			;Lsche IR_TEMP Register, dieses wird als temporres Register zur Zwischenspeicherung des IR-Bits verwendet
ir_rout_loop				;diese Schleife wird ausgefhrt bis COUNTER = 0
	clrf IR_BIT				;lsche IR-Bit Register
	rlf IR_TEMP				;Register wird um 1 nach links verschoben
							;Ermittlung des IR Signalpegels fr die 1.Hlfte des Bits
	movlw d'3'				;875us Zeitverzgerung bis zur ersten Abtastung = 3 x 256us, Rest = 107us
	movwf LOOP_1			;
	movlw d'107'			;Rest = 107us 
	call wait_us			;
	btfss IN_IR				;prfen ob IR-Eingangssignal high ist
	bsf IR_BIT,0			;wenn ja, berspringe diesen Befehl
	btfsc IN_IR				;prfen ob IR-Eingangssignal low ist
	bcf IR_BIT,0			;wenn ja, berspringe diesen Befehl
							;2.Hlfte							
	movlw d'3'				;875us Zeitverzgerung bis zur zweiten Abtastung = 3 x 256us, Rest = 107us
	movwf LOOP_1			;
	movlw d'107'			;Rest = 107us 
	call wait_us
	btfss IN_IR				;prfen ob IR-Eingangssignal high ist
	bsf IR_BIT,1			;wenn ja, berspringe diesen Befehl
	btfsc IN_IR				;prfen ob IR-Eingangssignal low ist
	bcf IR_BIT,1			;wenn ja, berspringe diesen Befehl
							;Auswertung
	movlw d'1'				;schreibe Wert 1 ins W-Register
	subwf IR_BIT,w			;subtrahiere Register IR_BIT (= 1 wenn Bit ist 0, = 2 wenn Bit ist 1)
	btfss STATUS,Z			;wenn Ergebnis = 0 , berspringe nchsten Befehl
	goto $+3				;Ergebnis ist nicht 0, weiter bei nchster Prfung
	bcf IR_TEMP,0			;Ergebnis ist 0, setze Bit 0 auf 0
	goto ir_loop_test		;weiter bei ir_loop_test
	movlw d'2'				;schreibe Wert 2 ins W-Register
	subwf IR_BIT,w			;subtrahiere Register IR_BIT (= 1 wenn Bit ist 0, = 2 wenn Bit ist 1)
	btfss STATUS,Z			;wenn Ergebnis = 0 , berspringe nchsten Befehl
	goto $+3				;Ergebnis ist nicht 0 = es ist ein Fehler aufgetreten
	bsf IR_TEMP,0			;Ergebnis ist 0, setze Bit 0 auf 1
	goto ir_loop_test		;weiter bei ir_loop_test
	bsf IR_BIT,2			;setze das Fehler Bit und springe zum Ende des Unterprogramms
	goto ir_rout_end

ir_loop_test
	decfsz COUNTER			;reduziere Zhler um 1 und prfe ob auf Null runtergezhlt
	goto ir_rout_loop		;Zhler ist nicht 0 ,zurck zur Schleife

ir_rout_end
	return

wait_us
	clrf LOOP_2
	subwf LOOP_2		;subtrahiere 
	movlw d'25'			;der erste loop wird um 25us verkrzt, da die Abarbeitung des Unterprogramms auch Zeit bentigt
	movwf TMR0			;
	bcf INTCON,T0IF
wait_us1
	btfss INTCON,T0IF
	goto wait_us1
	bcf INTCON,T0IF
	decfsz LOOP_1
	goto wait_us1
	movfw LOOP_2
	movwf TMR0
	btfss INTCON,T0IF
	goto $-1
	return



volume_change

	bcf OUT_CS_VOL
	nop
	bcf OUT_CLK_VOL
	nop
	bcf	OUT_SDI_VOL
	nop
	bsf OUT_CLK_VOL				;mit der positiven Flanke werden die Daten bernommen
	movfw VOL_BIN
	call vol_routine
	bcf OUT_CS_VOL
	nop
	bcf OUT_CLK_VOL
	nop
	bsf	OUT_SDI_VOL
	nop
	bsf OUT_CLK_VOL				;mit der positiven Flanke werden die Daten bernommen
	movfw VOL_BIN
	call vol_routine
	return



read_channel
	bcf INTCON,GIE				;Disable Interrupts 
	movfw CHANNEL				;kopiere die Kanalnr. ins TEMP_13 Register
	movwf TEMP_13				;
	decf TEMP_13				;Kanalnr. um eins reduzieren = EEPROM Speicherplatz fr Startvolumen
	movfw TEMP_13
	call readEE
	movwf VOLUME				;kopiere den im EEPROM gespeicherten Wert ins Volumenregister
	movfw CHANNEL				;kopiere die Kanalnr. ins TEMP_13 Register
	movwf TEMP_13				;
	bcf STATUS,C				;Lsche Carry Bit, damit es beim rotieren nicht strt
	rlf TEMP_13					;die Kanalnr. in TEMP_13 wird 3x nach links geschoben (mit 8 multipliziert), 
	rlf TEMP_13					;dieses ergibt die EEPROM Adresse fr das erste Text DIGIT
	rlf TEMP_13					;
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG1				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG2				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG3				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG4				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG5				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG6				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG7				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	incf TEMP_13
	movfw TEMP_13
	call readEE
	movwf TEXT_DIG8				;kopiere den im EEPROM gespeicherten Wert ins TEXT Register
	bsf INTCON,GIE				;Enable Interrupts 
	return


readEE							;Unterprogramm zum lesen der Zelle deren Adresse in W steht (internes EEPROM)
	bsf STATUS, RP1 			;EEADR liegt in der Bank 2 
	bcf STATUS, RP0
 	movwf EEADR 				;schreibe die Adresse in EEADR 
	bsf STATUS, RP0				;Bank 3
	bcf EECON1, EEPGD			;Access data memory
	bsf EECON1, RD 				;EEPROM Leseproze starten 
	bcf STATUS, RP0 			;Bank 2 
	movf EEDATA, W 				;Die Daten der EEPROM Zelle nach W kopieren 
	bcf STATUS, RP1 			;Bank 0 
	return

writeEE							;Unterprogramm zum Schreiben des Wertes in TEMP_13 an die Adresse, die in W steht (internes EEPROM)
	bsf STATUS, RP0				;Bank 3 (EECON1 ist in Bank 3)
	bsf STATUS, RP1
	btfsc EECON1, WR			;prfen, ob das EEPROM beschrieben werden kann
	goto $-1					;warten, bis das bit WR von der Hardware zurckgesetzt wurde
	bcf STATUS, RP0				;Bank 2 (EEADR und EEDATA sind in Bank 2)
	movwf EEADR					;Die Adresse an die die Daten geschrieben werden sollen ist im W-Register
	bcf STATUS, RP1				;Bank 0
	movfw TEMP_13				;hole zu speichernden Wert ins W-Register
	bsf STATUS, RP1				;Bank 2 (EEADR und EEDATA sind in Bank 2)
	movwf EEDATA				;Wert wird in EEADR geschrieben.
	bsf STATUS, RP0				;Bank 3
	bcf EECON1, EEPGD			;Das Bit EEPGD lschen, um das interne Daten-EEPROM auszuwhlen. Wird das Bit gesetzt, wird der Progamm-Flash ausgewhlt
	bsf EECON1, WREN			;erlaubt das Beschreiben des Daten-EEPROM
	bcf INTCON, GIE				;falls Interrupts verwendet werde, mssen diese abgeschaltet werden	
	movlw 0x55					;Um das EEPROM zu beschreiben, mssen die folgenden 5 Befehle
	movwf EECON2				;genau in dieser Reihenfolge aufgerufen werden.
	movlw 0xAA					;
	movwf EECON2				;
	bsf EECON1, WR				;Jetzt beginnt der eigentliche Schreibvorgang.
	bsf INTCON, GIE				;Die Interrupts knnen jetzt wieder freigegeben werden.
	bcf EECON1, WREN			;Das Beschreiben des EEPROM verbieten.
	bcf STATUS, RP0				;Bank 0
	bcf STATUS, RP1
	return						;Zurck ins Hauptprogramm



wait
	movlw d'250'			;loop_10 mu 4 Takten entsprechen fr 1ms: 4MHz /4/250/4Takte
	movwf LOOP_2
loop_10
	nop
	decfsz LOOP_2
	goto loop_10
	decfsz LOOP_1
	goto wait
	return




vol_routine
	movwf SHIFT_REG				;Register mit den Daten, die ausgegeben werden sollen
	bcf OUT_CLK_VOL				;Takt auf Low setzen, damit die Daten bei der steigenden Flanke bernommen werden knnen
	movlw d'8'					;es sollen 8 Bits bertragen werden
	movwf SHIFT_COUNT			;Zhler fr die bertragenen bits
shift_dat_vol
	rlf SHIFT_REG,F				;Das Zeichen wird nach links verschoben. Das Carryflag wird an den Ausgang weitergegeben
	btfsc STATUS,C				;Prfen, welchen Wert das Carryflag hat
	bsf OUT_SDI_VOL					;Carryflag = 1 -> Pin SI auf Highpegel setzen
	btfss STATUS,C				;Nochmal prfen, da immer nur ein Befehl bersprungen wird
	bcf OUT_SDI_VOL					;Carryflag = 0 -> Pin SI auf Lowpegel setzen
	nop							;kurze Wartezeit, um die bertragungsgeschwindigkeit zu reduzieren
	bsf OUT_CLK_VOL					;mit dieser steigenden Flanke werden die Daten bernommen
	nop							;kurze Wartezeit
	bcf OUT_CLK_VOL					;negative Flanke des Taktes
	decfsz SHIFT_COUNT,F		;ein bit wurde bertragen -> Zhler um 1 verringern
	goto shift_dat_vol			;nchstes bit bertragen
	bcf OUT_SDI_VOL					;Pin SI auf Low zurcksetzen
	bsf OUT_CS_VOL				;Chip Select auf High setzen
	return						;Rcksprung aus dem Unterprogramm

;*******************************************************************************************
;	UNTERPROGRAMME fr die Mensteuerung
;*******************************************************************************************

menue_stat						;Unterprogramms fr Menue Flip Flop
	btfss MENUE_FF,0			;prfen ob bit 0 gesetzt ist
	goto menue_bitset			;wenn ja berspringe diesen Befehl, wenn nein setze bit in Register
	clrf MENUE_FF				;lsche Register
	movlw d'1'
	movwf MENUE_COUNT			;lade Register mit Wert 1
	movwf TEMP_DIG_CNT			;
	clrf MENUE_1_CNT			;lsche Register
	bsf PCLATH,3				;Select Page 1
	movlw 0x0C					;Befehl: Display On/Off Control (00001100)
	call disp_befehl			;bertrage den Befehl an das Display
	call clear_display			;Aufruf des Unterprogramms zum Lschen des Displays
	movlw 0x06					;Befehl: Entry Mode Set (00000110)
	call disp_befehl			;bertrage den Befehl an das Display
	bcf PCLATH,3				;Select Page 0
	movlw 0xFF					;setze bit 0-7 auf high (=255) in Display Statusregister und TEMP_DIG_STAT Register
	movwf DISP_NEU				;
	clrf TEMP_DIG_STAT			;
	bsf TEMP_DIG_STAT,0			;
	goto menue_stat_end
menue_bitset
	bsf MENUE_FF,0				;setze bit in Register
	bsf DISP_NEU,4
menue_stat_end
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	call wait 		
	return

inc_dig_temp_cnt				;Unterprogramm zur Erhhung des Menpunktes horizontal
	movfw TEMP_CNT_MAX			;
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z				;prfen ob Zhler gleich dem Maximalwert ist
	goto $+4					;wenn ja, berspringe diesen Befehl	
	movlw d'1'
	movwf TEMP_DIG_CNT
	goto inc_temp_cnt_end
	incf TEMP_DIG_CNT
inc_temp_cnt_end
	bsf TEMP_DIG_STAT,0			;setze das Status bit
	return		

dec_dig_temp_cnt				;Unterprogramm zur Reduzierung des Menpunktes horizontal
	decfsz TEMP_DIG_CNT			;reduziere Zhler um 1 und prfe ob der der Zhler 0 ist
	goto dec_temp_cnt_end		;wenn ja, berspringe diesen Befehl	
	movfw TEMP_CNT_MAX			;
	movwf TEMP_DIG_CNT
dec_temp_cnt_end
	bsf TEMP_DIG_STAT,0			;setze das Status bit
	return

;*******************************************************************************************
; Volumentabelle
;*******************************************************************************************

	ORG 0x6FF

volume_tab
	addwf PCL,f
	retlw d'0'			;Datenpunkt 0
	retlw d'0'			;Datenpunkt 1
	retlw d'1'			;Datenpunkt 2
	retlw d'2'			;Datenpunkt 3
	retlw d'3'			;Datenpunkt 4
	retlw d'4'			;Datenpunkt 5
	retlw d'5'			;Datenpunkt 6
	retlw d'6'			;Datenpunkt 7
	retlw d'7'			;Datenpunkt 8
	retlw d'8'			;Datenpunkt 9
	retlw d'9'			;Datenpunkt 10
	retlw d'11'			;Datenpunkt 11
	retlw d'13'			;Datenpunkt 12
	retlw d'15'			;Datenpunkt 13
	retlw d'18'			;Datenpunkt 14
	retlw d'21'			;Datenpunkt 15
	retlw d'25'			;Datenpunkt 16
	retlw d'29'			;Datenpunkt 17
	retlw d'33'			;Datenpunkt 18
	retlw d'38'			;Datenpunkt 19
	retlw d'44'			;Datenpunkt 20
	retlw d'52'			;Datenpunkt 21
	retlw d'60'			;Datenpunkt 22
	retlw d'69'			;Datenpunkt 23
	retlw d'80'			;Datenpunkt 24
	retlw d'92'			;Datenpunkt 25
	retlw d'107'		;Datenpunkt 26
	retlw d'124'		;Datenpunkt 27
	retlw d'143'		;Datenpunkt 28
	retlw d'165'		;Datenpunkt 29
	retlw d'191'		;Datenpunkt 30
	retlw d'221'		;Datenpunkt 31
	retlw d'255'		;Datenpunkt 32

;*******************************************************************************************
;	PAGE 1, 	bsf PCLATH,3				;Select Page 1
;				bcf PCLATH,4
;*******************************************************************************************
	ORG 0x800					;PAGE 1

;*******************************************************************************************
; Weitere Unterprogramme zur Mensteuerung
;*******************************************************************************************

dig_startvol1				;Unterprogramm zur Erhhung/Reduzierung der Werte im Menuepunkt 1.Startvolume
	movlw d'1'				;prfen ob der 1. Wert verndert werden soll,
	subwf TEMP_DIG_CNT,w	;
	btfss STATUS, Z			;prfen ob Ergebniss =0		
	goto dig_startvol2		;wenn ja, berspringe diesen Befehl, wenn nein weiter bei nchster Prfung
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_startvol1	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_startvol1		;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf CHANNEL			;Bit ist gesetzt, erhhe Zhler um 1
	movlw d'9'				;lade Wert 9 ins W-Register
	subwf CHANNEL,w			;subtrahiere Wert nach Erhhung
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_startvol1	;
	movlw d'1'				;Rcksetzen des Registers mit Wert 1	
	movwf CHANNEL			;
	goto cursor_startvol1
dec_startvol1
	decfsz CHANNEL			;Reduziere Register und prfe ob 0
	goto cursor_startvol1	;Wert >0
	movlw d'8'				;Rcksetzen des Registers 
	movwf CHANNEL
cursor_startvol1
	bcf PCLATH,3			;Select Page 0
	call read_channel		;Aufruf des Unterprogramms zum lesen des Kanalnamens aus dem EEPROM
	bsf PCLATH,3			;Select Page 1
	movlw 0x89				;lade Adresse ins W-Register
	call disp_befehl		;bertrage das Kommando zum setzen der DDRAM-Adresse
	call disp_namen			;Aufruf des Unterprogramms zum Schreiben des Kanalnamens
	movlw 0xC8				;lade Adresse ins W-Register zum Anzeigen des Volumens
	call disp_befehl		;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw VOLUME			;Ausgabe des gespeicherte Volumen auf dem Display
	call convert_dig		;Aufruf des Unterprogramms zum Auftrennen in 10er und 1er
	movfw TEMP_14			;Daten fr 10er, untere 4 Bit
	addlw b'00110000'		;addiere obere 4 bit
	call disp_daten			;bertrage das Zeichen
	movfw TEMP_15			;Daten fr 1er, untere 4 Bit
	addlw b'00110000'		;addiere obere 4 bit
	call disp_daten			;bertrage das Zeichen

	movlw 0x87				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw CHANNEL			;hole Wert in temporres Register
	addlw b'00110000'		;addiere obere 4 bit
	movwf TEMP_DIG_VAL
	movlw 0x20				;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_startvol_end	;springe zum Ende des Unterprogramms
dig_startvol2
	movlw d'2'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_startvol_end
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_startvol2	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_startvol2		;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf VOLUME
	movlw d'31'
	subwf VOLUME,w
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_startvol2 	;springe zum Ende des Unterprogramms
	clrf VOLUME				;Rcksetzen des Registers mit Wert 0	
	goto cursor_startvol2
dec_startvol2
	movfw VOLUME			;hole Wert ins W-Register
	btfsc STATUS,Z			;prfe ob Wert <0>
	goto $+3				;wenn ja berspringe diesen Befehl, wenn nein setze Register auf 0
	decf VOLUME				;reduziere Zhler um 1
	goto $+3				;schiebe Wert in temporres Display Register
	movlw d'30'
	movwf VOLUME
cursor_startvol2
	movlw 0xC9				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw VOLUME			;
	call convert_dig		;Aufruf des Unterprogramms zum Auftrennen in 10er und 1er
	movfw TEMP_15
	addlw b'00110000'		;addiere obere 4 bit
	movwf TEMP_DIG_VAL
	movfw TEMP_14			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	addlw b'00110000'		;addiere obere 4 bit
	movwf TEMP_VAL_PREV
	goto dig_startvol_end
dig_startvol_end
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_DIG_VAL			;Daten fr das zu schreibende Zeichen, untere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	decf TEMP_DIG_ADR,w			;Reduziere die Adresse um 1
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_VAL_PREV			;Daten fr das zu schreibende Zeichen
	call disp_daten				;bertrage das Zeichen
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	clrf TEMP_DIG_STAT			;lsche Statusbit Register
	return

dig_automan1
	movlw d'1'					;prfen ob TEMP_DIG_CNT =1
	subwf TEMP_DIG_CNT,w		;
	btfss STATUS,Z				;
	goto dig_automan2			;TEMP_DIG_CNT >1<, weiter bei nchster Prfung
	clrf TEMP_10				;TEMP_DIG_CNT =1, lsche Register (0) fr Poti Typ AD5262
	movlw 0xC0					;
	movwf TEMP_DIG_ADR			;
	goto dig_automan_end		;
dig_automan2
	movlw d'2'					;prfen ob TEMP_DIG_CNT =1
	subwf TEMP_DIG_CNT,w		;
	btfss STATUS,Z				;
	goto dig_automan_end		;TEMP_DIG_CNT >2<, weiter bei ende des Unterprogramms
	movlw d'1'					;TEMP_DIG_CNT =1, lade Wert 1 in Register fr Poti Typ Eigenbau
	movwf TEMP_10
	movlw 0xC5					;
	movwf TEMP_DIG_ADR			;
dig_automan_end
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	clrf TEMP_DIG_STAT			;lsche Statusbit Register
	return	

dig_name1					;Unterprogramm zur Erhhung/Reduzierung der Werte im Menuepunkt 2.Kanalname
	movlw d'1'				;prfen ob der 1. Wert verndert werden soll,
	subwf TEMP_DIG_CNT,w	;
	btfss STATUS, Z			;prfen ob Ergebniss =0		
	goto dig_name2			;wenn ja, berspringe diesen Befehl, wenn nein weiter bei nchster Prfung
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_name1		;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_name1			;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf CHANNEL			;Bit ist gesetzt, erhhe Zhler um 1
	movlw d'9'				;lade Wert 9 ins W-Register
	subwf CHANNEL,w			;subtrahiere Wert nach Erhhung
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_name1	;
	movlw d'1'				;Rcksetzen des Registers mit Wert 1	
	movwf CHANNEL			;
	goto cursor_name1
dec_name1
	decfsz CHANNEL			;Reduziere Register und prfe ob 0
	goto cursor_name1		;Wert >0
	movlw d'8'				;Rcksetzen des Registers 
	movwf CHANNEL
cursor_name1
	bcf PCLATH,3			;Select Page 0
	call read_channel		;Aufruf des Unterprogramms zum lesen des Kanalnamens aus dem EEPROM
	bsf PCLATH,3			;Select Page 1
	movlw 0xC6				;lade Adresse ins W-Register
	call disp_befehl		;bertrage das Kommando zum setzen der DDRAM-Adresse
	call disp_namen			;Aufruf des Unterprogramms zum Schreiben des Kanalnamens

	movlw 0x87				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw CHANNEL			;hole Wert in temporres Register
	addlw b'00110000'		;addiere obere 4 bit
	movwf TEMP_DIG_VAL
	movlw 0x20				;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end		;springe zum Ende des Unterprogramms
dig_name2
	movlw d'2'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name3
	movfw TEXT_DIG1			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG1
	movlw 0xC6				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movlw 0x20				;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name3
	movlw d'3'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name4
	movfw TEXT_DIG2			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG2
	movlw 0xC7				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG1			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name4
	movlw d'4'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name5
	movfw TEXT_DIG3			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG3
	movlw 0xC8				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG2			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name5
	movlw d'5'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name6
	movfw TEXT_DIG4			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG4
	movlw 0xC9				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG3			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name6
	movlw d'6'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name7
	movfw TEXT_DIG5			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG5
	movlw 0xCA				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG4			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name7
	movlw d'7'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name8
	movfw TEXT_DIG6			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG6
	movlw 0xCB				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG5			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name8
	movlw d'8'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name9
	movfw TEXT_DIG7			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG7
	movlw 0xCC				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG6			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name9
	movlw d'9'
	subwf TEMP_DIG_CNT,w
	btfss STATUS, Z		
	goto dig_name_end
	movfw TEXT_DIG8			;kopiere das TEXT_DIG Register in das TEMP_DIG_VAL Register
	movwf TEMP_DIG_VAL
	call dig_name_routine
	movfw TEMP_DIG_VAL		;Rckschreiben des genderten TEMP_DIG_VAL Wertes in das TEXT_DIG Register
	movwf TEXT_DIG8
	movlw 0xCD				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEXT_DIG7			;schiebe Wert in temporres Display Register fr Wert der vorhergehenden Adresse
	movwf TEMP_VAL_PREV
	goto dig_name_end
dig_name_end
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_DIG_VAL			;Daten fr das zu schreibende Zeichen, untere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	decf TEMP_DIG_ADR,w			;Reduziere die Adresse um 1
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_VAL_PREV			;Daten fr das zu schreibende Zeichen
	call disp_daten				;bertrage das Zeichen
	bcf TEMP_DIG_STAT,0			;lsche das Status bit
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	clrf TEMP_DIG_STAT			;lsche Statusbit Register
	return

dig_name_routine
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto dig_name_rout_end	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_name			;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf TEMP_DIG_VAL
	movlw d'91'
	subwf TEMP_DIG_VAL,w
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto dig_name_rout_end	;springe zum Ende des Unterprogramms
	movlw 0x20				;Rcksetzen des Registers mit Wert 32 = blank
	movwf TEMP_DIG_VAL			;
	goto dig_name_rout_end
dec_name
	decf TEMP_DIG_VAL		;reduziere Zhler um 1
	movlw 0x1F				;hole Wert 31 ins W-Register
	subwf TEMP_DIG_VAL,w	;subtrahiere Register
	btfss STATUS,Z			;prfe ob Ergebnis = 0
	goto dig_name_rout_end	;Ergebnis ist nicht 0, weiter bei setzen der cursor daten
	movlw d'90'				;Rcksetzen des Zhlers mit Wert 90 => ASCI: Z
	movwf TEMP_DIG_VAL
dig_name_rout_end
	return

dig_kanalzahl
	btfss BEFEHL,3			;Prfen ob Bit fr Befehl "up" gesetzt ist
	goto dec_kanalzahl		;Bit ist nicht gesetzt, weiter bei nchster Prfung
	incf TEMP_DIG_VAL		;erhhe Wert um 1
	movlw d'9'				;hole Wert 9 ins W-Register und subtrahiere den Zhler nach Erhhung
	subwf TEMP_DIG_VAL,w
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto dig_kanalzahl_end	;Ergebnis >0<, springe zum Ende des Unterprogramms
	movlw 0x01				;Ergebnis ist 0, Rcksetzen des Registers mit Wert 1
	movwf TEMP_DIG_VAL		;
	goto dig_kanalzahl_end
dec_kanalzahl
	btfss BEFEHL,4			;Prfen ob Bit fr Befehl "down" gesetzt ist
	goto dig_kanalzahl_end	;Bit ist nicht gesetzt, weiter zum Ende des Unterprogramms
	decfsz TEMP_DIG_VAL		;reduziere Wert um 1 und prfe ob Ergebnis =0
 	goto dig_kanalzahl_end	;Ergebnis >0<, springe zum Ende des Unterprogramms	
	movlw d'8'				;Ergebnis ist 0, Rcksetzen des Registers mit Wert 8
	movwf TEMP_DIG_VAL	
dig_kanalzahl_end
	movlw 0x8D				;Adresse fr das zu schreibende Zeichen
	call disp_befehl		;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_DIG_VAL		;Daten fr das zu schreibende Zeichen, untere 4 bit
	addlw b'00110000'		;addiere obere 4 bit	
	call disp_daten			;bertrage das Zeichen
	movlw 0x8C				;Adresse fr das zu schreibende Zeichen
	call disp_befehl		;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw 0x20				;Daten fr das zu schreibende Zeichen
	call disp_daten			;bertrage das Zeichen
	movlw d'250'			;Wartezeit von 250ms
	movwf LOOP_1			;
	bcf PCLATH,3			;Select Page 0
	call wait 		
	bsf PCLATH,3			;Select Page 1
	clrf TEMP_DIG_STAT		;lsche Statusbit Register
	return

dig_iradrbef				;Unterprogramm zur Erhhung/Reduzierung der Werte im Menuepunkt 5+6
	movlw d'1'				;prfen ob der 1. Wert verndert werden soll,
	subwf TEMP_DIG_CNT,w	;
	btfss STATUS, Z			;prfen ob Ergebniss =0		
	goto dig_iradrbef2		;wenn ja, berspringe diesen Befehl, wenn nein weiter bei nchster Prfung
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_iradrbef1	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_iradrbef1		;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf TEMP_10			;Bit ist gesetzt, erhhe Zhler um 1
	movfw TEMP_18			;lade Maximalwert+1 ins W-Register
	subwf CHANNEL,w			;subtrahiere Wert nach Erhhung
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_iradrbef1	;
	clrf TEMP_10			;Rcksetzen des Registers mit Wert 0
	goto cursor_iradrbef1
dec_iradrbef1
	movfw TEMP_10			;hole Wert ins W-Register
	btfsc STATUS,Z			;prfe ob Wert <0>
	goto $+3				;Wert ist 0, Rcksetzen des Zhlers
	decf TEMP_10			;Wert ist noch nicht 0, reduziere Zhler um 1
	goto $+4				;
	movfw TEMP_18			;Rcksetzen des Zhlers mit dem Maximalwert+1
	movwf TEMP_10
	decf TEMP_10			;reduziere Zhler um 1
cursor_iradrbef1
	movlw 0x86				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEMP_10			;hole Wert in temporres Register
	movwf TEMP_DIG_VAL
	goto dig_iradrbef_end	;springe zum Ende des Unterprogramms
dig_iradrbef2
	movlw d'2'				;prfen ob der 2. Wert verndert werden soll,
	subwf TEMP_DIG_CNT,w	;
	btfss STATUS, Z			;prfen ob Ergebniss =0		
	goto dig_iradrbef3		;wenn ja, berspringe diesen Befehl, wenn nein weiter bei nchster Prfung
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_iradrbef2	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_iradrbef2		;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf TEMP_11			;Bit ist gesetzt, erhhe Zhler um 1
	movfw TEMP_18			;lade Maximalwert+1 ins W-Register
	subwf CHANNEL,w			;subtrahiere Wert nach Erhhung
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_iradrbef2	;
	clrf TEMP_11			;Rcksetzen des Registers mit Wert 0
	goto cursor_iradrbef2
dec_iradrbef2
	movfw TEMP_11			;hole Wert ins W-Register
	btfsc STATUS,Z			;prfe ob Wert <0>
	goto $+3				;Wert ist 0, Rcksetzen des Zhlers
	decf TEMP_11			;Wert ist noch nicht 0, reduziere Zhler um 1
	goto $+4				;
	movfw TEMP_18			;Rcksetzen des Zhlers mit dem Maximalwert+1
	movwf TEMP_11
	decf TEMP_11			;reduziere Zhler um 1
cursor_iradrbef2
	movlw 0x8E				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEMP_11			;hole Wert in temporres Register
	movwf TEMP_DIG_VAL
	goto dig_iradrbef_end	;springe zum Ende des Unterprogramms
dig_iradrbef3
	movlw d'3'				;prfen ob der 1. Wert verndert werden soll,
	subwf TEMP_DIG_CNT,w	;
	btfss STATUS, Z			;prfen ob Ergebniss =0		
	goto dig_iradrbef_end	;wenn ja, berspringe diesen Befehl, wenn nein weiter bei nchster Prfung
	btfsc TEMP_DIG_STAT,0	;prfen ob die Cursor Position sich gendert hat
	goto cursor_iradrbef3	;Cursor Position hat sich verndert, gehe zu update Cursor
	btfss TEMP_DIG_STAT,1	;prfen ob Bit fr Erhhung des zu ndernden Wertes gesetzt ist
	goto dec_iradrbef3		;Bit ist nicht gesetzt, gehe zu Reduzierung des zu ndernden Wertes
	incf TEMP_12			;Bit ist gesetzt, erhhe Zhler um 1
	movfw TEMP_18			;lade Maximalwert+1 ins W-Register
	subwf CHANNEL,w			;subtrahiere Wert nach Erhhung
	btfss STATUS,Z			;prfen ob Ergebnis =0
 	goto cursor_iradrbef3	;
	clrf TEMP_12			;Rcksetzen des Registers mit Wert 0
	goto cursor_iradrbef3
dec_iradrbef3
	movfw TEMP_12			;hole Wert ins W-Register
	btfsc STATUS,Z			;prfe ob Wert <0>
	goto $+3				;Wert ist 0, Rcksetzen des Zhlers
	decf TEMP_12			;Wert ist noch nicht 0, reduziere Zhler um 1
	goto $+4				;
	movfw TEMP_18			;Rcksetzen des Zhlers mit dem Maximalwert+1
	movwf TEMP_12
	decf TEMP_12			;reduziere Zhler um 1
cursor_iradrbef3
	movlw 0xC6				;lade Adresse ins W-Register
	movwf TEMP_DIG_ADR		;speichere Adresse im temp-Register
	movfw TEMP_12			;hole Wert in temporres Register
	movwf TEMP_DIG_VAL
	goto dig_iradrbef_end	;springe zum Ende des Unterprogramms
dig_iradrbef_end
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_DIG_VAL			;Daten fr das zu schreibende Zeichen
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 10er und 1er
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	decf TEMP_DIG_ADR,w			;Reduziere die Adresse um 1
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	clrf TEMP_DIG_STAT			;lsche Statusbit Register
	return

dig_poti1
	movlw d'1'					;prfen ob TEMP_DIG_CNT =1
	subwf TEMP_DIG_CNT,w		;
	btfss STATUS,Z				;
	goto dig_poti2				;TEMP_DIG_CNT >1<, weiter bei nchster Prfung
	clrf TEMP_10				;TEMP_DIG_CNT =1, lsche Register (0) fr Poti Typ AD5262
	movlw 0xC0					;
	movwf TEMP_DIG_ADR			;
	goto dig_poti_end			;
dig_poti2
	movlw d'2'					;prfen ob TEMP_DIG_CNT =1
	subwf TEMP_DIG_CNT,w		;
	btfss STATUS,Z				;
	goto dig_poti_end			;TEMP_DIG_CNT >2<, weiter bei ende des Unterprogramms
	movlw d'1'					;TEMP_DIG_CNT =1, lade Wert 1 in Register fr Poti Typ Eigenbau
	movwf TEMP_10
	movlw 0xC7					;
	movwf TEMP_DIG_ADR			;
dig_poti_end
	movfw TEMP_DIG_ADR			;Adresse fr das zu schreibende Zeichen
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	clrf TEMP_DIG_STAT			;lsche Statusbit Register
	return	


;*******************************************************************************************
; Unterprogramme fr die Anzeige auf dem LCD Display
;*******************************************************************************************

disp_normal
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movfw CHANNEL				;Daten fr Kanal
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	call disp_namen				;Aufruf des Unterprogramms zum Schreiben des Kanalnamens
	btfss CHA_AUTO,0
	goto $+8
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	goto $+7
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	btfsc IN_KH					;prfen ob kein Kopfhrer angeschlossen ist (Eingang low)
	goto $+6					;Kopfhrer ist angeschlossen, schreibe KH bei $+6
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	goto $+5
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'H'					;ASCII:
	call disp_daten				;bertrage das Zeichen

	movlw 0xC2					;Zeichen 3 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'V'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'o'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movfw VOLUME				;Daten fr Volume
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	btfsc OUT_SHD_VOL
	goto $+3
	movlw A'M'
	goto $+2
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	btfss OUT_BASS
	goto $+3
	movlw A'B'
	goto $+2
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	bcf DISP_NEU,0				;Lsche das Statusbit
	return

disp_namen
	movfw TEXT_DIG1				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG2				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG3				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG4				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG5				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG6				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG7				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	movfw TEXT_DIG8				;Text fr Kanal
	call disp_daten				;bertrage das Zeichen
	return

disp_menue_1
	call clear_display		;Aufruf des Unterprogramms zum Lschen des Displays
	movlw d'1'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_2
	call dispm1_startvol
	goto disp_menue_end
disp_menue_2
	movlw d'2'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_3
	call dispm1_automan
	goto disp_menue_end
disp_menue_3
	movlw d'3'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_4
	call dispm1_kanalname
	goto disp_menue_end
disp_menue_4
	movlw d'4'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_5
	call dispm1_kanalzahl
	goto disp_menue_end
disp_menue_5
	movlw d'5'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_6
	call dispm1_irtest
	goto disp_menue_end
disp_menue_6
	movlw d'6'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_7
	call dispm1_iradr
	goto disp_menue_end
disp_menue_7
	movlw d'7'				;
	subwf MENUE_COUNT, w	;
	btfss STATUS,Z		
	goto disp_menue_end
	call dispm1_irbef
disp_menue_end
	bcf DISP_NEU,4
	return

dispm1_startvol
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'1'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'S'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'v'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'o'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_automan
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'2'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'g'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_kanalname
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'3'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_kanalzahl
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'4'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'z'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'h'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_irtest
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'5'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'I'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'R'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'T'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_iradr
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'6'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'I'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'R'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'd'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

dispm1_irbef
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'7'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'.'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'I'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'R'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'B'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'f'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'h'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

disp_set_startvol
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
								;2.Reihe
	movlw 0xC0					;Zeichen 1 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'V'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'o'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
	return

disp_set_automan
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'g'					;ASCII:
	call disp_daten				;bertrage das Zeichen
								;2.Zeile
	movlw 0xC1					;Zeichen 2 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'o'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'M'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return


disp_set_name
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
								;2.Reihe
	movlw 0xC0					;Zeichen 1 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'N'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'm'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
	return

disp_set_kanalzahl
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'z'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'h'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw b'00111010'			;Daten fr ":"
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;Daten fr blank
	call disp_daten				;bertrage das Zeichen
	return


disp_set_irtest
	call clear_display
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'd'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movfw IR_ADR				;Daten fr RC5 IR-Adresse
	addlw 0x01					;bei Fehler ist IR adresse 255. Durch Addition von 1 wird Ergebniss 0
	btfss STATUS,Z				;prfe ob 0
	goto write_adr 				;Ergebnis nicht 0 (kein Fehler)
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen				
	goto disp_set_irtest2
write_adr
	movfw IR_ADR				;Daten fr RC5 IR-Adresse
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_13				;Daten 100er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
disp_set_irtest2
	movlw 0xC0					;Zeichen 1 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'B'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'f'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'h'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movfw IR_BEF				;Daten fr RC5 IR-Adresse
	addlw 0x01					;bei Fehler ist IR adresse 255. Durch Addition von 1 wird Ergebniss 0
	btfss STATUS,Z				;prfe ob 0
	goto write_bef				;Ergebnis nicht 0 (kein Fehler)
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'F'					;ASCII:
	call disp_daten				;bertrage das Zeichen				
	goto disp_irtest_end
write_bef
	movfw IR_BEF				;Daten fr RC5 IR-Adresse
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_13				;Daten 100er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
disp_irtest_end
	movlw d'250'				;Wartezeit von 250ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	bcf IR_BIT,2				;lsche IR-Fehlerbit
	bcf IR_NEU,0				;lsche Statusbit
	bsf INTCON,INTE				;setze Interruptbit
	return

disp_set_iradr
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'd'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'1'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_ADR_1				;daten fr 1.RC5-Adresse
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'd'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'2'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_ADR_2				;daten fr 2.RC5-Adresse
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw 0xC0					;Zeichen 1 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'd'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'r'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'3'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_ADR_3				;daten fr 3.RC5-Adresse
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	return

disp_set_irbef
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'M'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_BEF_MEN			;daten fr RC5-Befehl Men
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'O'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'K'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_BEF_OK				;daten fr RC5-Befehl OK
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movlw 0xC0					;Zeichen 1 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'B'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A':'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movfw IR_BEF_BAS			;daten fr RC5-Befehl Bassanhebung
	call convert_dig			;Aufruf des Unterprogramms zum Auftrennen in 100er, 10er und 1er
	movfw TEMP_14				;Daten 10er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	movfw TEMP_15				;Daten 1er, untere 4 bit
	addlw b'00110000'			;addiere obere 4 bit
	call disp_daten				;bertrage das Zeichen
	return

disp_set_poti
	movlw 0x80					;Zeichen 1 in der 1. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'P'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'o'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A't'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'i'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A's'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'w'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'h'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'l'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0xC1					;Zeichen 2 in der 2. Zeile
	call disp_befehl			;bertrage das Kommando zum setzen der DDRAM-Adresse
	movlw A'A'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'D'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'5'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'2'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'6'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'2'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw 0x20					;blank
	call disp_daten				;bertrage das Zeichen
	movlw A'E'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'i'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'g'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'e'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'n'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'b'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'a'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	movlw A'u'					;ASCII:
	call disp_daten				;bertrage das Zeichen
	return

	

Init_display					;Unterprogramm zur Initialisierung des Displays
	movlw d'250'				;geforderte Wartezeit des Displays von 200ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	movlw 0x38					;Befehl: Function Set
	call disp_befehl			;
	movlw 0x39					;Befehl: Function Set, (muss zweimal bertragen werden)
	call disp_befehl			;
	movlw 0x14					;Befehl: Bias Set
	call disp_befehl			;
	movlw 0x78					;Befehl: Contrast Set
	call disp_befehl			;
	movlw 0x52					;Befehl: Power/Icon/Contrast Contr.
	call disp_befehl			;
	movlw 0x69					;Befehl: Follower Control
	call disp_befehl			;
	movlw d'250'				;geforderte Wartezeit des Displays von 200ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	movlw 0x0C					;Befehl: Display On/Off Control (00001100)
	call disp_befehl			;
	call clear_display			;Aufruf des Unterprogramms zum Lschen des Displays
	movlw 0x06					;Befehl: Entry Mode Set (00000110)
	call disp_befehl			;
	return

clear_display					;Unterprogramm zum lschen des Displays					
	movlw 0x01					;Befehl: Clear Display
	call disp_befehl			;
	movlw d'2'					;geforderte Wartezeit des Displays von 1,08ms
	movwf LOOP_1				;
	bcf PCLATH,3				;Select Page 0
	call wait 		
	bsf PCLATH,3				;Select Page 1
	return

cursor_off
	movlw 0x0C					;Befehl: Display On/Off Control, Cursor OFF (00001100)
	call disp_befehl			;
	movlw d'20'					;Wartezeit min 27us
	movwf LOOP_1				;
	decfsz LOOP_1				;
	goto $-1
	return

cursor_on
	movlw 0x0E					;Befehl: Display On/Off Control, Cursor ON (00001110)
	call disp_befehl			;
	movlw d'20'					;geforderte Wartezeit min 27us
	movwf LOOP_1				;
	decfsz LOOP_1				;
	goto $-1
	return


disp_befehl
	movwf SHIFT_REG				;Register mit den Daten, die ausgegeben werden sollen
	bsf OUT_ENABLE				;Enable auf High setzen
	nop
	nop
	bcf OUT_RS					;RS auf Low setzen, da es sich um ein Kommando handelt
	call disp_routine			;Aufruf des Unterprogramms zum Schreiben der Display Adresse / Daten
	return

disp_daten
	movwf SHIFT_REG				;Das W-Register wird in das Reg. DISP_SHIFT_REG kopiert
	bsf OUT_ENABLE				;Enable auf High setzen
	nop
	nop
	bsf OUT_RS					;RS auf High setzen, da es sich um ein Zeichen handelt
	call disp_routine			;Aufruf des Unterprogramms zum Schreiben der Display Adresse / Daten
	return

disp_routine
	bcf OUT_CLK					;Takt auf Low setzen, damit die Daten bei der steigenden Flanke bernommen werden knnen
	movlw d'8'					;es sollen 8 Bits bertragen werden
	movwf SHIFT_COUNT			;Zhler fr die bertragenen bits
shift_daten
	rlf SHIFT_REG,F				;Das Zeichen wird nach links verschoben. Das Carryflag wird an den Ausgang weitergegeben
	btfsc STATUS,C				;Prfen, welchen Wert das Carryflag hat
	bsf OUT_SDA					;Carryflag = 1 -> Pin SI auf Highpegel setzen
	btfss STATUS,C				;Nochmal prfen, da immer nur ein Befehl bersprungen wird
	bcf OUT_SDA					;Carryflag = 0 -> Pin SI auf Lowpegel setzen
	nop							;kurze Wartezeit, um die bertragungsgeschwindigkeit zu reduzieren
	bsf OUT_CLK					;mit dieser steigenden Flanke werden die Daten bernommen
	nop							;kurze Wartezeit
	bcf OUT_CLK					;negative Flanke des Taktes
	decfsz SHIFT_COUNT,F		;ein bit wurde bertragen -> Zhler um 1 verringern
	goto shift_daten			;nchstes bit bertragen
	bcf OUT_ENABLE				;Enable auf low setzen, mit der negativen Flanke werden Daten bertragen 
	bcf OUT_RS					;bertragung beendet Pin RS auf Low zurcksetzen
	bcf OUT_SDA					;Pin SI auf Low zurcksetzen
	movlw d'30'					;geforderte Wartezeit (min. 26,3 us)
	movwf LOOP_1
	decfsz LOOP_1
	goto $-1
	return						;Rcksprung aus dem Unterprogramm

convert_dig					;Unterprogramm zur Umwandlung von zB Zahl 123 in 1,2,3
	movwf TEMP_17			;Temp Register fr Zwischenspeicherung des zu zerlegenden Wertes
	clrf TEMP_16			;lsche Temp Register
	clrf TEMP_13			;lsche Temp Register
loop_100er
	movfw TEMP_17
	movwf TEMP_16
	movlw d'100'			;schreibe Wert 100 ins W-Register
	subwf TEMP_17			;reduziere den zu zerlegenden Werte um 100
	btfss STATUS,C
	goto loop_100er_end
	incf TEMP_13			;Temp Register fr Zwischenspeicherung 100er
	goto loop_100er
loop_100er_end
	clrf TEMP_14			;lsche Temp Register fr Zwischenspeicherung 10er
loop_10er
	movfw TEMP_16
	movwf TEMP_15			;Temp Register fr Zwischenspeicherung 1er
	movlw d'10'
	subwf TEMP_16
	btfss STATUS,C
	goto loop_10er_end
	incf TEMP_14			;Temp Register fr Zwischenspeicherung 10er
	goto loop_10er
loop_10er_end
	return

	END                			; Ende des Programms


